@@ -17,10 +17,10 @@ import os
 
 import pkg_resources
 
-from .dispatcher import InitDispatcher
-from .settings import settings as stgs
-from .streams import BUILTIN_STREAM_SETS, BUILTIN_STREAMS
-from .utils import prepend_base_path
+from avocado.core.dispatcher import InitDispatcher
+from avocado.core.settings import settings as stgs
+from avocado.core.streams import BUILTIN_STREAM_SETS, BUILTIN_STREAMS
+from avocado.core.utils.path import prepend_base_path
 
 
 def register_core_options():
@@ -140,6 +140,7 @@ def register_core_options():
                          key_type=int,
                          help_msg=help_msg,
                          default=10)
+
     help_msg = ('Whether to display colored output in terminals that '
                 'support it')
     stgs.register_option(section='runner.output',
@@ -188,6 +189,33 @@ def register_core_options():
                          key_type=list,
                          help_msg=help_msg)
 
+    help_msg = ('By default Avocado runners will use the {uri} of a test as '
+                'its identifier. Use a custom f-string identifier in order to '
+                'change it.')
+    stgs.register_option(section='runner',
+                         key='identifier_format',
+                         default="{uri}",
+                         help_msg=help_msg)
+
+    help_msg = 'List of test references (aliases or paths)'
+    stgs.register_option(section='resolver',
+                         key='references',
+                         key_type=list,
+                         default=[],
+                         help_msg=help_msg)
+
+    help_msg = ('Selects the runner implementation from one of the '
+                'installed and active implementations.  You can run '
+                '"avocado plugins" and find the list of valid runners '
+                'under the "Plugins that run test suites on a job '
+                '(runners) section.  Defaults to "nrunner", which is '
+                'the new runner.  To use the conventional and traditional '
+                'runner, use "runner".')
+    stgs.register_option(section='run',
+                         key='test_runner',
+                         default='nrunner',
+                         help_msg=help_msg)
+
 
 def initialize_plugin_infrastructure():
     help_msg = 'Plugins that will not be loaded and executed'
