@@ -10,6 +10,7 @@ import json
 import multiprocessing
 import os
 import re
+import shutil
 import socket
 import subprocess
 import sys
@@ -52,7 +53,7 @@ def check_runnables_runner_requirements(runnables, runners_registry=None):
     Checks if runnables have runner requirements fulfilled
 
     :param runnables: the tasks whose runner requirements will be checked
-    :type runnable: list of :class:`Runnable`
+    :type runnables: list of :class:`Runnable`
     :param runners_registry: a registry with previously found (and not found)
                              runners keyed by a task's runnable kind. Defaults
                              to :attr:`RUNNERS_REGISTRY_STANDALONE_EXECUTABLE`
@@ -102,7 +103,12 @@ class ConfigEncoder(json.JSONEncoder):
     def default(self, config_option):  # pylint: disable=W0221
         if isinstance(config_option, set):
             return {'__encoded_set__': list(config_option)}
-        return json.JSONEncoder.default(self, config_option)
+        try:
+            return json.JSONEncoder.default(self, config_option)
+        except TypeError:
+            # Probably this is a not JSON serializable data. To keep the same
+            # behavior as before, lets return None
+            return None
 
 
 class Runnable:
@@ -121,6 +127,7 @@ class Runnable:
         self.tags = kwargs.pop('tags', None)
         self.requirements = kwargs.pop('requirements', None)
         self.variant = kwargs.pop('variant', None)
+        self.output_dir = kwargs.pop('output_dir', None)
         self.kwargs = kwargs
 
     def __repr__(self):
@@ -130,6 +137,57 @@ class Runnable:
                           self.kwargs, self.tags, self.requirements,
                           self.variant)
 
+    @property
+    def identifier(self):
+        """Runnable identifier respecting user's format string.
+
+        This is still experimental and we have room for improvements.
+
+        This property it will return an unique identifier for this runnable.
+        Please use this property in order to respect user's customization.
+
+        By default runnables has its '{uri}' as identifier.
+
+        Custom formatter can be configured and currently we accept the
+        following values as normal f-strings replacements: {uri}, {args},
+        and {kwargs}. "args" and "kwargs" are special cases.
+
+        For args, since it is a list, you can use in two different ways:
+        "{args}" for the entire list, or "{args[n]}" for a specific element
+        inside this list.  The same is valid when using "{kwargs}". With
+        kwargs, since it is a dictionary, you have to specify a key as index
+        and then the values are used. For instance if you have a kwargs value
+        named 'DEBUG', a valid usage could be: "{kwargs[DEBUG]}" and this will
+        print the current value to this variable (i.e: True or False).
+
+        Since this is formatter, combined values can be used. Example:
+        "{uri}-{args}".
+        """
+        fmt = self.config.get("runner.identifier_format")
+
+        # For the cases where there is no config (when calling the Runnable
+        # directly
+        if not fmt:
+            return self.uri
+
+        # For args we can use the entire list of arguments or with a specific
+        # index.
+        args = '-'.join(self.args)
+        if 'args' in fmt and '[' in fmt:
+            args = self.args
+
+        # For kwargs we can use the entire list of values or with a specific
+        # index.
+        kwargs = '-'.join(self.kwargs.values())
+        if 'kwargs' in fmt and '[' in fmt:
+            kwargs = self.kwargs
+
+        options = {'uri': self.uri,
+                   'args': args,
+                   'kwargs': kwargs}
+
+        return fmt.format(**options)
+
     @classmethod
     def from_args(cls, args):
         """Returns a runnable from arguments"""
@@ -174,7 +232,7 @@ class Runnable:
             args.append('-u')
             args.append(self.uri)
 
-        if self.config is not None:
+        if self.config:
             args.append('-c')
             args.append(json.dumps(self.config, cls=ConfigEncoder))
 
@@ -190,6 +248,9 @@ class Runnable:
         if self.variant is not None:
             args.append('variant=json:%s' % json.dumps(self.variant))
 
+        if self.output_dir is not None:
+            args.append('output_dir=%s' % self.output_dir)
+
         for key, val in self.kwargs.items():
             if not isinstance(val, str) or isinstance(val, int):
                 val = "json:%s" % json.dumps(val)
@@ -217,6 +278,8 @@ class Runnable:
             kwargs['tags'] = self.get_serializable_tags()
         if self.variant is not None:
             kwargs['variant'] = self.variant
+        if self.output_dir is not None:
+            kwargs['output_dir'] = self.output_dir
         if kwargs:
             recipe['kwargs'] = kwargs
         return recipe
@@ -245,14 +308,15 @@ class Runnable:
         with open(recipe_path, 'w') as recipe_file:
             recipe_file.write(self.get_json())
 
-    def is_kind_supported_by_runner_command(self, runner_command):
+    def is_kind_supported_by_runner_command(self, runner_command, env=None):
         """Checks if a runner command that seems a good fit declares support."""
         cmd = runner_command + ['capabilities']
         try:
             process = subprocess.Popen(cmd,
                                        stdin=subprocess.DEVNULL,
                                        stdout=subprocess.PIPE,
-                                       stderr=subprocess.DEVNULL)
+                                       stderr=subprocess.DEVNULL,
+                                       env=env)
         except (FileNotFoundError, PermissionError):
             return False
         out, _ = process.communicate()
@@ -264,6 +328,18 @@ class Runnable:
 
         return self.kind in capabilities.get('runnables', [])
 
+    @staticmethod
+    def _module_exists(module_name):
+        """Returns whether a nrunner "runner" module exists."""
+        module_filename = '%s.py' % module_name
+        if PKG_RESOURCES_AVAILABLE:
+            mod_path = os.path.join('core', 'runners', module_filename)
+            return pkg_resources.resource_exists('avocado', mod_path)
+
+        core_dir = os.path.dirname(os.path.abspath(__file__))
+        mod_path = os.path.join(core_dir, 'runners', module_filename)
+        return os.path.exists(mod_path)
+
     def pick_runner_command(self, runners_registry=None):
         """Selects a runner command based on the runner.
 
@@ -290,6 +366,11 @@ class Runnable:
         if runner_cmd is not None:
             return runner_cmd
 
+        # When running Avocado Python modules, the interpreter on the new
+        # process needs to know where Avocado can be found.
+        env = os.environ.copy()
+        env['PYTHONPATH'] = ':'.join(p for p in sys.path)
+
         standalone_executable_cmd = ['avocado-runner-%s' % self.kind]
         if self.is_kind_supported_by_runner_command(standalone_executable_cmd):
             runners_registry[self.kind] = standalone_executable_cmd
@@ -299,16 +380,22 @@ class Runnable:
         # runner convention within the avocado.core namespace dir.
         # Looking for the file only avoids an attempt to load the module
         # and should be a lot faster
-        core_dir = os.path.dirname(os.path.abspath(__file__))
         module_name = self.kind.replace('-', '_')
-        module_filename = '%s.py' % module_name
-        if os.path.exists(os.path.join(core_dir, 'runners', module_filename)):
+        if self._module_exists(module_name):
             full_module_name = 'avocado.core.runners.%s' % module_name
             candidate_cmd = [sys.executable, '-m', full_module_name]
-            if self.is_kind_supported_by_runner_command(candidate_cmd):
+            if self.is_kind_supported_by_runner_command(candidate_cmd,
+                                                        env):
                 runners_registry[self.kind] = candidate_cmd
                 return candidate_cmd
 
+        # look for the runner commands implemented in the base nrunner module
+        candidate_cmd = [sys.executable, '-m', 'avocado.core.nrunner']
+        if self.is_kind_supported_by_runner_command(candidate_cmd,
+                                                    env):
+            runners_registry[self.kind] = candidate_cmd
+            return candidate_cmd
+
         # exhausted probes, let's save the negative on the cache and avoid
         # future similar problems
         runners_registry[self.kind] = False
@@ -473,27 +560,68 @@ class ExecTestRunner(BaseRunner):
         final_status['returncode'] = process.returncode
         return self.prepare_status('finished', final_status)
 
+    def _cleanup(self):
+        """Cleanup method for the exec-test tests"""
+        # cleanup temporary directories
+        workdir = self.runnable.kwargs.get('AVOCADO_TEST_WORKDIR')
+        if (workdir is not None and
+                self.runnable.config.get('run.keep_tmp') is not None and
+                os.path.exists(workdir)):
+            shutil.rmtree(workdir)
+
     def _create_params(self):
         """Create params for the test"""
-        # inject the -p command-line / run.test_parameters option in the
-        # environment variables
-        params = dict(self.runnable.config.get('run.test_parameters', []))
-
-        if self.runnable.variant is not None:
-            params_from_variant = dict([(str(key), str(val)) for _, key, val in
-                                        self.runnable.variant['variant'][0][1]])
-            # if we have params from the variant, replace the original params
-            if params_from_variant:
-                params = params_from_variant
+        if self.runnable.variant is None:
+            return {}
 
+        params = dict([(str(key), str(val)) for _, key, val in
+                       self.runnable.variant['variant'][0][1]])
         return params
 
+    @staticmethod
+    def _get_avocado_version():
+        """Return the Avocado package version, if installed"""
+        version = "unknown.unknown"
+        if PKG_RESOURCES_AVAILABLE:
+            try:
+                version = pkg_resources.get_distribution(
+                    'avocado-framework').version
+            except pkg_resources.DistributionNotFound:
+                pass
+        return version
+
+    def _get_env_variables(self):
+        """Get the default AVOCADO_* environment variables
+
+        These variables are available to the test environment during the test
+        execution.
+        """
+        # create the temporary work dir
+        workdir = tempfile.mkdtemp(prefix='.avocado-workdir-')
+        # create the avocado environment variable dictionary
+        avocado_test_env_variables = {
+            'AVOCADO_VERSION': self._get_avocado_version(),
+            'AVOCADO_TEST_WORKDIR': workdir,
+        }
+        if self.runnable.output_dir:
+            avocado_test_env_variables['AVOCADO_TEST_OUTPUTDIR'] = \
+                self.runnable.output_dir
+        return avocado_test_env_variables
+
     def run(self):
-        env = None
+        env = dict(os.environ)
         if self.runnable.kwargs:
-            current = dict(os.environ)
-            current.update(self.runnable.kwargs)
-            env = current
+            env.update(self.runnable.kwargs)
+
+        # set default Avocado environment variables if running on a valid Task
+        if self.runnable.uri is not None:
+            avocado_test_env_variables = self._get_env_variables()
+            # save environment variables for further cleanup
+            self.runnable.kwargs.update(avocado_test_env_variables)
+            if env is None:
+                env = avocado_test_env_variables
+            else:
+                env.update(avocado_test_env_variables)
 
         params = self._create_params()
         if params:
@@ -512,6 +640,7 @@ class ExecTestRunner(BaseRunner):
             yield self.prepare_status('started')
             yield self.prepare_status('finished', {'result': 'error',
                                                    'fail_reason': str(e)})
+            self._cleanup()
             return
 
         yield self.prepare_status('started')
@@ -535,6 +664,7 @@ class ExecTestRunner(BaseRunner):
         yield self.prepare_status('running', {'type': 'stdout', 'log': stdout})
         yield self.prepare_status('running', {'type': 'stderr', 'log': stderr})
         yield self._process_final_status(process, stdout, stderr)
+        self._cleanup()
 
 
 RUNNERS_REGISTRY_PYTHON_CLASS['exec-test'] = ExecTestRunner
@@ -569,7 +699,7 @@ class PythonUnittestRunner(BaseRunner):
         It will return ("test", "Class", "test_foo")
         """
 
-        uri = self.runnable.uri
+        uri = self.runnable.uri or ''
         if ':' in uri:
             module, class_method = uri.rsplit(':', 1)
         else:
@@ -841,7 +971,6 @@ class Task:
         self.known_runners = known_runners
         self.dependencies = set()
         self.spawn_handle = None
-        self.output_dir = None
         self.metadata = {}
 
     def __repr__(self):
@@ -861,10 +990,10 @@ class Task:
             runners_registry = RUNNERS_REGISTRY_STANDALONE_EXECUTABLE
         return self.runnable.pick_runner_command(runners_registry)
 
-    def setup_output_dir(self):
-        self.output_dir = tempfile.mkdtemp(prefix='.avocado-task-')
-        env_var = {'AVOCADO_TEST_OUTPUTDIR': self.output_dir}
-        self.runnable.kwargs.update(env_var)
+    def setup_output_dir(self, output_dir=None):
+        if not self.runnable.output_dir:
+            output_dir = output_dir or tempfile.mkdtemp(prefix='.avocado-task-')
+            self.runnable.output_dir = output_dir
 
     @classmethod
     def from_recipe(cls, task_path, known_runners):
@@ -915,7 +1044,7 @@ class Task:
         runner = runner_klass(self.runnable)
         for status in runner.run():
             if status['status'] == 'started':
-                status.update({'output_dir': self.output_dir})
+                status.update({'output_dir': self.runnable.output_dir})
             status.update({"id": self.identifier})
             if self.job_id is not None:
                 status.update({"job_id": self.job_id})
