@@ -16,17 +16,17 @@ import os
 from enum import Enum
 from uuid import uuid4
 
-from .dispatcher import RunnerDispatcher
-from .exceptions import (JobTestSuiteReferenceResolutionError,
-                         OptionValidationError)
-from .loader import (DiscoverMode, LoaderError, LoaderUnhandledReferenceError,
-                     loader)
-from .parser import HintParser
-from .resolver import ReferenceResolutionResult, resolve
-from .settings import settings
-from .tags import filter_test_tags, filter_test_tags_runnable
-from .test import DryRunTest, Test
-from .varianter import Varianter, is_empty_variant
+from avocado.core.dispatcher import RunnerDispatcher
+from avocado.core.exceptions import (JobTestSuiteReferenceResolutionError,
+                                     OptionValidationError)
+from avocado.core.loader import (DiscoverMode, LoaderError,
+                                 LoaderUnhandledReferenceError, loader)
+from avocado.core.parser import HintParser
+from avocado.core.resolver import ReferenceResolutionResult, resolve
+from avocado.core.settings import settings
+from avocado.core.tags import filter_test_tags, filter_test_tags_runnable
+from avocado.core.test import DryRunTest, Test
+from avocado.core.varianter import Varianter, is_empty_variant
 
 
 class TestSuiteError(Exception):
@@ -84,10 +84,11 @@ def resolutions_to_runnables(resolutions, config):
 
 class TestSuite:
     def __init__(self, name, config=None, tests=None, job_config=None,
-                 resolutions=None):
+                 resolutions=None, enabled=True):
         self.name = name
         self.tests = tests
         self.resolutions = resolutions
+        self.enabled = enabled
 
         # Create a complete config dict with all registered options + custom
         # config
@@ -98,7 +99,7 @@ class TestSuite:
             self.config.update(config)
 
         # Update the config of runnables.
-        if config.get('run.test_runner') == 'nrunner' and self.tests:
+        if self.config.get('run.test_runner') == 'nrunner' and self.tests:
             for test in self.tests:
                 test.config.update(self.config)
 
@@ -150,7 +151,7 @@ class TestSuite:
 
     @classmethod
     def _from_config_with_loader(cls, config, name=None):
-        references = config.get('run.references')
+        references = config.get('resolver.references')
         ignore_missing = config.get('run.ignore_missing_references')
         verbose = config.get('core.verbose')
         subcommand = config.get('subcommand')
@@ -186,7 +187,7 @@ class TestSuite:
     @classmethod
     def _from_config_with_resolver(cls, config, name=None):
         ignore_missing = config.get('run.ignore_missing_references')
-        references = config.get('run.references')
+        references = config.get('resolver.references')
         try:
             hint = None
             hint_filepath = '.avocado.hint'
@@ -209,7 +210,7 @@ class TestSuite:
     def _get_stats_from_nrunner(self):
         stats = {}
         for test in self.tests:
-            stats = self._increment_dict_key_counter(stats, test.kind)
+            self._increment_dict_key_counter(stats, test.kind)
         return stats
 
     def _get_stats_from_runner(self):
@@ -219,7 +220,7 @@ class TestSuite:
         for cls, _ in self.tests:
             if isinstance(cls, str):
                 cls = Test
-            stats = self._increment_dict_key_counter(stats, mapping[cls])
+            self._increment_dict_key_counter(stats, mapping[cls])
         return stats
 
     def _get_tags_stats_from_nrunner(self):
@@ -229,7 +230,7 @@ class TestSuite:
                 continue
             tags = runnable.tags or {}
             for tag in tags:
-                stats = self._increment_dict_key_counter(stats, tag)
+                self._increment_dict_key_counter(stats, tag)
         return stats
 
     def _get_tags_stats_from_runner(self):
@@ -237,7 +238,7 @@ class TestSuite:
         for test in self.tests:
             params = test[1]
             for tag in params.get('tags', {}):
-                stats = self._increment_dict_key_counter(stats, tag)
+                self._increment_dict_key_counter(stats, tag)
         return stats
 
     @staticmethod
@@ -246,18 +247,17 @@ class TestSuite:
             dict_object[key.lower()] += 1
         except KeyError:
             dict_object[key.lower()] = 1
-        return dict_object
 
     @property
     def references(self):
         if self._references is None:
-            self._references = self.config.get('run.references')
+            self._references = self.config.get('resolver.references')
         return self._references
 
     @property
     def runner(self):
         if self._runner is None:
-            runner_name = self.config.get('run.test_runner') or 'runner'
+            runner_name = self.config.get('run.test_runner')
             try:
                 runner_extension = RunnerDispatcher()[runner_name]
                 self._runner = runner_extension.obj
@@ -275,7 +275,7 @@ class TestSuite:
     @property
     def stats(self):
         """Return a statistics dict with the current tests."""
-        runner_name = self.config.get('run.test_runner') or 'runner'
+        runner_name = self.config.get('run.test_runner')
         if runner_name == 'runner':
             return self._get_stats_from_runner()
         elif runner_name == 'nrunner':
@@ -296,7 +296,7 @@ class TestSuite:
     @property
     def tags_stats(self):
         """Return a statistics dict with the current tests tags."""
-        runner_name = self.config.get('run.test_runner') or 'runner'
+        runner_name = self.config.get('run.test_runner')
         if runner_name == 'runner':
             return self._get_tags_stats_from_runner()
         elif runner_name == 'nrunner':
@@ -364,7 +364,7 @@ class TestSuite:
         config.update(suite_config)
         if job_config:
             config.update(job_config)
-        runner = config.get('run.test_runner') or 'runner'
+        runner = config.get('run.test_runner')
         if runner == 'nrunner':
             suite = cls._from_config_with_resolver(config, name)
         else:
