@@ -32,15 +32,15 @@ import time
 import unittest
 from difflib import unified_diff
 
-from ..utils import asset, astring, data_structures, genio
-from ..utils import path as utils_path
-from ..utils import process, stacktrace
-from . import exceptions, output, parameters, sysinfo, tapparser
-from .decorators import skip
-from .output import LOG_JOB
-from .settings import settings
-from .test_id import TestID
-from .version import VERSION
+from avocado.core import exceptions, output, parameters, sysinfo, tapparser
+from avocado.core.decorators import skip
+from avocado.core.output import LOG_JOB
+from avocado.core.settings import settings
+from avocado.core.test_id import TestID
+from avocado.core.version import VERSION
+from avocado.utils import asset, astring, data_structures, genio
+from avocado.utils import path as utils_path
+from avocado.utils import process, stacktrace
 
 #: Environment variable used to store the location of a temporary
 #: directory which is preserved across all tests execution (usually in
@@ -276,13 +276,18 @@ class Test(unittest.TestCase, TestData):
             self.__base_logdir_tmp = tempfile.TemporaryDirectory(prefix=prefix)
             self.__base_logdir = self.__base_logdir_tmp.name
 
-        self.__base_logdir = os.path.join(self.__base_logdir, 'test-results')
-        logdir = os.path.join(self.__base_logdir, self.name.str_filesystem)
-        if os.path.exists(logdir):
-            raise exceptions.TestSetupFail("Log dir already exists, this "
-                                           "should never happen: %s"
-                                           % logdir)
-        self.__logdir = utils_path.init_dir(logdir)
+        if self._config.get("run.test_runner") == 'nrunner':
+            logdir = self.__base_logdir
+            self.__logdir = logdir
+        else:
+            self.__base_logdir = os.path.join(self.__base_logdir, 'test-results')
+            logdir = os.path.join(self.__base_logdir, self.name.str_filesystem)
+
+            if os.path.exists(logdir):
+                raise exceptions.TestSetupFail("Log dir already exists, this "
+                                               "should never happen: %s"
+                                               % logdir)
+            self.__logdir = utils_path.init_dir(logdir)
         self.__logfile = os.path.join(self.logdir, 'debug.log')
 
         self._stdout_file = os.path.join(self.logdir, 'stdout')
@@ -642,34 +647,6 @@ class Test(unittest.TestCase, TestData):
         for name, handler in self._logging_handlers.items():
             logging.getLogger(name).removeHandler(handler)
 
-    def _record_reference(self, produced_file_path, reference_file_name):
-        '''
-        Saves a copy of a file produced by the test into a reference file
-
-        This utility method will copy the produced file into the expected
-        reference file location, which can later be used for comparison
-        on subsequent test runs.
-
-        Note: A reference file is a "golden" file with content that is
-        expected to match what was produced during the test.  If the
-        produced content matches the reference file content, the test
-        performed correctly.
-
-        :param produced_file_path: the location of the file that was produced
-                                   by this test execution
-        :type produced_file_path: str
-        :param reference_file_name: the name of the file that will be used on
-                                    subsequent runs to check the test produced
-                                    the correct content.  This file will be
-                                    saved into a location obtained by
-                                    calling :meth:`get_data()`.
-        :type reference_file_name: str
-        '''
-        reference_path = self.get_data(reference_file_name, must_exist=False)
-        if reference_path is not None:
-            utils_path.init_dir(os.path.dirname(reference_path))
-            shutil.copyfile(produced_file_path, reference_path)
-
     def _check_reference(self, produced_file_path, reference_file_name,
                          diff_file_name, child_log_name, name='Content'):
         '''
@@ -730,22 +707,13 @@ class Test(unittest.TestCase, TestData):
         """
         Auxiliary method to run_avocado.
         """
-        # If the test contains an output.expected file, it requires
-        # changing the mode of operation of the process.* utility
-        # methods, so that after the test finishes, the output
-        # produced can be compared to the expected one.  This runs in
-        # its own process, so the change should not effect other
-        # components using process.* functions.
-        if self.get_data('output.expected') is not None:
-            process.OUTPUT_CHECK_RECORD_MODE = 'combined'
-
         testMethod = getattr(self, self._testMethodName)
-        self._start_logging()
+        if self._config.get("run.test_runner") != 'nrunner':
+            self._start_logging()
         if self.__sysinfo_enabled:
             self.__sysinfo_logger.start()
         test_exception = None
         cleanup_exception = None
-        output_check_exception = None
         stdout_check_exception = None
         stderr_check_exception = None
         skip_test_condition = getattr(testMethod, '__skip_test_condition__', False)
@@ -823,66 +791,11 @@ class Test(unittest.TestCase, TestData):
         whiteboard_file = os.path.join(self.logdir, 'whiteboard')
         genio.write_file(whiteboard_file, self.whiteboard)
 
-        output_check_record = self._config.get('run.output_check_record')
-        output_check = self._config.get('run.output_check')
-
-        # record the output if the modes are valid
-        if output_check_record == 'combined':
-            self._record_reference(self._output_file,
-                                   "output.expected")
-        else:
-            if output_check_record in ['all', 'both', 'stdout']:
-                self._record_reference(self._stdout_file,
-                                       "stdout.expected")
-            if output_check_record in ['all', 'both', 'stderr']:
-                self._record_reference(self._stderr_file,
-                                       "stderr.expected")
-
-        # check the output and produce test failures
-        if output_check_record != 'none' and output_check:
-            output_checked = False
-            try:
-                output_checked = self._check_reference(
-                    self._output_file,
-                    'output.expected',
-                    'output.diff',
-                    'output_diff',
-                    'Output')
-            except exceptions.TestFail as details:
-                stacktrace.log_exc_info(sys.exc_info(),
-                                        logger=LOG_JOB)
-                output_check_exception = details
-            if not output_checked:
-                try:
-                    self._check_reference(self._stdout_file,
-                                          'stdout.expected',
-                                          'stdout.diff',
-                                          'stdout_diff',
-                                          'Stdout')
-                except exceptions.TestFail as details:
-                    # output check was performed (and failed)
-                    output_checked = True
-                    stacktrace.log_exc_info(sys.exc_info(),
-                                            logger=LOG_JOB)
-                    stdout_check_exception = details
-                try:
-                    self._check_reference(self._stderr_file,
-                                          'stderr.expected',
-                                          'stderr.diff',
-                                          'stderr_diff',
-                                          'Stderr')
-                except exceptions.TestFail as details:
-                    stacktrace.log_exc_info(sys.exc_info(),
-                                            logger=LOG_JOB)
-                    stderr_check_exception = details
-
         # pylint: disable=E0702
         if test_exception is not None:
             raise test_exception
         elif cleanup_exception is not None:
             raise cleanup_exception
-        elif output_check_exception is not None:
-            raise output_check_exception
         elif stdout_check_exception is not None:
             raise stdout_check_exception
         elif stderr_check_exception is not None:
@@ -1210,105 +1123,6 @@ class SimpleTest(Test):
         self._execute_cmd()
 
 
-class ExternalRunnerSpec:
-    """
-    Defines the basic options used by ExternalRunner
-    """
-
-    def __init__(self, runner, chdir=None, test_dir=None):
-        self.runner = runner
-        self.chdir = chdir
-        self.test_dir = test_dir
-
-
-class ExternalRunnerTest(SimpleTest):
-
-    def __init__(self, name, params=None, base_logdir=None, config=None,
-                 external_runner=None, external_runner_argument=None):
-        if external_runner_argument is None:
-            external_runner_argument = name.name
-        if external_runner is None:
-            raise ValueError("External runner test requires a valid "
-                             "external_runner parameter, got None instead.")
-        self.external_runner = external_runner
-        super(ExternalRunnerTest, self).__init__(name, params, base_logdir,
-                                                 config)
-        self._command = "%s %s" % (external_runner.runner,
-                                   external_runner_argument)
-
-    @property
-    def filename(self):
-        return None
-
-    def test(self):
-        pre_cwd = os.getcwd()
-        new_cwd = None
-        try:
-            self.log.info('Running test with the external test runner: "%s"',
-                          self.external_runner.runner)
-
-            # Change work directory if needed by the external runner
-            if self.external_runner.chdir == 'runner':
-                new_cwd = os.path.dirname(self.external_runner.runner)
-            elif self.external_runner.chdir == 'test':
-                new_cwd = self.external_runner.test_dir
-            else:
-                new_cwd = None
-            if new_cwd is not None:
-                self.log.debug('Changing working directory to "%s" '
-                               'because of external runner requirements ',
-                               new_cwd)
-                os.chdir(new_cwd)
-
-            self._execute_cmd()
-
-        finally:
-            if new_cwd is not None:
-                os.chdir(pre_cwd)
-
-
-class PythonUnittest(ExternalRunnerTest):
-    """
-    Python unittest test
-    """
-
-    def __init__(self, name, params=None, base_logdir=None, config=None,
-                 test_dir=None, python_unittest_module=None,
-                 tags=None):    # pylint: disable=W0613
-        runner = "%s -m unittest -q -c" % sys.executable
-        external_runner = ExternalRunnerSpec(runner, "test", test_dir)
-        super(PythonUnittest, self).__init__(name, params, base_logdir, config,
-                                             external_runner=external_runner,
-                                             external_runner_argument=python_unittest_module)
-
-    def _find_result(self, status="OK"):
-        status_line = "[stderr] %s" % status
-        with open(self.logfile) as logfile:
-            lines = iter(logfile)
-            for line in lines:
-                if "[stderr] Ran 1 test in" in line:
-                    break
-            for line in lines:
-                if status_line in line:
-                    return line
-        self.error("Fail to parse status from test result.")
-
-    def test(self):
-        try:
-            super(PythonUnittest, self).test()
-        except exceptions.TestFail:
-            status = self._find_result("FAILED")
-            if "errors" in status:
-                self.error("Unittest reported error(s)")
-            elif "failures" in status:
-                self.fail("Unittest reported failure(s)")
-            else:
-                self.error("Unknown failure executing the unittest")
-        status = self._find_result("OK")
-        if "skipped" in status:
-            raise exceptions.TestSkipError("Unittest reported skip")
-
-
 class TapTest(SimpleTest):
 
     """
@@ -1325,7 +1139,6 @@ class TapTest(SimpleTest):
             input_encoding = self._config.get('core.input_encoding')
             result = process.run(self._command,
                                  verbose=True,
-                                 allow_output_check='stdout',
                                  env=test_params,
                                  encoding=input_encoding)
 
@@ -1438,31 +1251,3 @@ class DryRunTest(MockingTest):
                 return None
         except AttributeError:
             return None
-
-
-class ReplaySkipTest(MockingTest):
-
-    """
-    Skip test due to job replay filter.
-
-    This test is skipped due to a job replay filter.
-    It will never have a chance to execute.
-    """
-
-    @skip('Test skipped due to a job replay filter!')
-    def test(self):
-        pass
-
-
-class TestError(Test):
-    """
-    Generic test error.
-    """
-
-    def __init__(self, *args, **kwargs):
-        exception = kwargs.pop('exception')
-        Test.__init__(self, *args, **kwargs)
-        self.exception = exception
-
-    def test(self):
-        self.error(self.exception)
