@@ -26,11 +26,10 @@ from avocado.core.output import LOG_UI
 from avocado.core.plugin_interfaces import CLICmd
 from avocado.core.settings import settings
 from avocado.core.spawners.exceptions import SpawnerException
+from avocado.plugins.spawners.podman import PodmanSpawner
+from avocado.plugins.spawners.process import ProcessSpawner
 from avocado.utils import astring
 
-from .spawners.podman import PodmanSpawner
-from .spawners.process import ProcessSpawner
-
 
 class Jobs(CLICmd):
     """
