@@ -22,7 +22,7 @@ import os
 import platform
 import re
 
-LOGGER = logging.getLogger('avocado.test')
+LOGGER = logging.getLogger(__name__)
 
 __all__ = ['LinuxDistro',
            'UNKNOWN_DISTRO_NAME',
@@ -436,6 +436,18 @@ class OpenEulerProbe(Probe):
     CHECK_VERSION_REGEX = re.compile(r'openEuler release (\d+)\.(\d+).*')
 
 
+class UnionTechProbe(Probe):
+
+    """
+    Simple probe for UnionTech systems in general
+    """
+
+    CHECK_FILE = '/etc/UnionTech-release'
+    CHECK_FILE_CONTAINS = 'uos release'
+    CHECK_FILE_DISTRO_NAME = 'uos'
+    CHECK_VERSION_REGEX = re.compile(r'uos release (\d+)\.(\d+).*')
+
+
 #: the complete list of probes that have been registered
 REGISTERED_PROBES = []
 
@@ -456,6 +468,7 @@ register_probe(DebianProbe)
 register_probe(SUSEProbe)
 register_probe(UbuntuProbe)
 register_probe(OpenEulerProbe)
+register_probe(UnionTechProbe)
 
 
 def detect(session=None):
