@@ -25,9 +25,9 @@ import shutil
 import time
 import warnings
 
-from . import process
+from avocado.utils import process
 
-LOGGER = logging.getLogger('avocado.test')
+LOGGER = logging.getLogger(__name__)
 
 
 class LVException(Exception):
