@@ -21,9 +21,9 @@ import ast
 import logging
 import time
 
-from . import distro, process, service, wait
+from avocado.utils import distro, process, service, wait
 
-LOG = logging.getLogger('avocado.test')
+LOG = logging.getLogger(__name__)
 
 
 class MPException(Exception):
