@@ -20,16 +20,14 @@ import json
 import logging
 import os
 import shutil
-import warnings
 from ipaddress import ip_interface
 
-from ..distro import detect as distro_detect
-from ..process import CmdError
-from ..wait import wait_for
-from .common import run_command
-from .exceptions import NWException
+from avocado.utils.distro import detect as distro_detect
+from avocado.utils.network.common import run_command
+from avocado.utils.network.exceptions import NWException
+from avocado.utils.wait import wait_for
 
-log = logging.getLogger('avocado.test')
+LOG = logging.getLogger(__name__)
 
 
 class NetworkInterface:
@@ -57,10 +55,32 @@ class NetworkInterface:
         elif current_distro.name == 'SuSE':
             path = "/etc/sysconfig/network"
         else:
-            msg = 'Distro not supported by API. Could get interface filename.'
+            msg = 'Distro not supported by API. Could not get interface filename.'
             raise NWException(msg)
         return "{}/ifcfg-{}".format(path, self.name)
 
+    @property
+    def config_file_path(self):
+        current_distro = distro_detect()
+        if current_distro.name in ['rhel', 'fedora']:
+            return "/etc/sysconfig/network-scripts"
+        elif current_distro.name == 'SuSE':
+            return "/etc/sysconfig/network"
+        else:
+            msg = 'Distro not supported by API. Could not get interface filename.'
+            LOG.error(msg)
+
+    @property
+    def slave_config_filename(self):
+        try:
+            slave_dict = self._get_bondinterface_details()
+            return ["{}/ifcfg-{}".format(self.config_file_path,
+                    slave) for slave in slave_dict['slaves']]
+        except Exception:
+            msg = "Slave config filename not available"
+            LOG.debug(msg)
+            return
+
     def _get_interface_details(self, version=None):
         cmd = "ip -j link show {}".format(self.name)
         if version:
@@ -74,9 +94,19 @@ class NetworkInterface:
             raise NWException("Interface not found")
         except (NWException, json.JSONDecodeError):
             msg = "Unable to get the details of interface {}".format(self.name)
-            log.error(msg)
+            LOG.error(msg)
             raise NWException(msg)
 
+    def _get_bondinterface_details(self):
+        cmd = "cat /sys/class/net/{}/bonding/mode \
+               /sys/class/net/{}/bonding/slaves".format(self.name, self.name)
+        try:
+            mode, slaves = run_command(cmd, self.host).splitlines()
+            return {'mode': mode.split(),
+                    'slaves': slaves.split()}
+        except Exception:
+            raise NWException("Slave interface not found for the bond {}".format(self.name))
+
     def _move_file_to_backup(self, filename, ignore_missing=True):
         destination = "{}.backup".format(filename)
         if os.path.exists(filename):
@@ -286,7 +316,7 @@ class NetworkInterface:
                 return [x.get('local') for x in addr_info]
         except (NWException, IndexError):
             msg = "Could not get ip addresses for {}".format(self.name)
-            log.debug(msg)
+            LOG.debug(msg)
             return []
 
     def get_hwaddr(self):
@@ -301,23 +331,6 @@ class NetworkInterface:
         except Exception as ex:
             raise NWException("Failed to get hw address: {}".format(ex))
 
-    def get_link_state(self):
-        """Method used to get the current link state of this interface.
-
-        This method will return 'up', 'down' or 'unknown', based on the
-        network interface state. Or it will raise a NWException if is
-        unable to get the interface state.
-        """
-        warnings.warn("deprecated, use existing methods: is_operational_link_up,\
-                       is_admin_link_up", DeprecationWarning)
-        cmd = "cat /sys/class/net/{}/operstate".format(self.name)
-        try:
-            return run_command(cmd, self.host)
-        except CmdError as e:
-            msg = ('Failed to get link state. Maybe the interface is '
-                   'missing. {}'.format(e))
-            raise NWException(msg)
-
     def get_mtu(self):
         """Return the current MTU value of this interface.
 
@@ -391,6 +404,35 @@ class NetworkInterface:
                       'IPV6_DEFROUTE': 'yes'}
         if current_distro.name == 'SuSE':
             ifcfg_dict.pop('BOOTPROTO')
+
+        if self.if_type == 'Bond':
+            ifcfg_dict['BONDING_MASTER'] = 'yes'
+            bond_dict = self._get_bondinterface_details()
+            ifcfg_slave_dict = {'SLAVE': 'yes',
+                                'ONBOOT': 'yes',
+                                'MASTER': self.name}
+            if current_distro.name == 'SuSE':
+                ifcfg_dict['BONDING_MODULE_OPTS'] = 'mode=' \
+                           + bond_dict['mode'][0]
+                for index, slave in enumerate(bond_dict['slaves']):
+                    bonding_slave = 'BONDING_SLAVE{}'.format(index)
+                    ifcfg_dict[bonding_slave] = slave
+                    ifcfg_slave_dict.update({'NAME': slave,
+                                             'DEVICE': slave})
+                    self._write_to_file("{}/ifcfg-{}".format(path, slave),
+                                        ifcfg_slave_dict)
+            elif current_distro.name in ['rhel', 'fedora']:
+                ifcfg_dict['BONDING_OPTS'] = 'mode='+bond_dict['mode'][0]
+                for index, slave in enumerate(bond_dict['slaves']):
+                    ifcfg_slave_dict.update({'NAME': slave,
+                                             'DEVICE': slave,
+                                             'TYPE': 'Ethernet'})
+                    self._write_to_file("{}/ifcfg-{}".format(path, slave),
+                                        ifcfg_slave_dict)
+            else:
+                msg = 'Distro not supported by API. Could not save ipaddr.'
+                raise NWException(msg)
+
         self._write_to_file("{}/{}".format(path, filename), ifcfg_dict)
 
     def set_mtu(self, mtu, timeout=30):
@@ -474,7 +516,23 @@ class NetworkInterface:
             return True
         except Exception as ex:
             msg = "Interface {} is not available. {}".format(self.name, ex)
-            log.debug(msg)
+            LOG.debug(msg)
+            return False
+
+    def is_bond(self):
+        """Check if interface is a bonding device.
+
+        This method checks if the interface is a bonding device or not.
+
+        rtype: bool
+        """
+        cmd = 'cat /proc/net/bonding/{}'.format(self.name)
+        try:
+            run_command(cmd, self.host)
+            return True
+        except Exception as ex:
+            msg = "{} is not a bond device. {}".format(self.name, ex)
+            LOG.debug(msg)
             return False
 
     def remove_cfg_file(self):
@@ -483,3 +541,20 @@ class NetworkInterface:
         """
         if os.path.isfile(self.config_filename):
             os.remove(self.config_filename)
+
+    def restore_slave_cfg_file(self):
+        """
+        Restore or delete slave config files.
+        """
+        if self.if_type != 'Bond':
+            return
+        for slave_config in self.slave_config_filename:
+            backup_slave_config = "{}.backup".format(slave_config)
+            try:
+                if os.path.exists(backup_slave_config):
+                    shutil.move(backup_slave_config, slave_config)
+                else:
+                    os.remove(slave_config)
+            except Exception as ex:
+                raise NWException("Could not restore \
+                                  the config file {}".format(ex))
