@@ -24,7 +24,7 @@ Module for all PCI devices related functions.
 import os
 import re
 
-from . import genio, process
+from avocado.utils import genio, process
 
 
 def get_domains():
@@ -95,14 +95,10 @@ def get_disks_in_pci_address(pci_address):
 
     :return: list of disks in a PCI address.
     """
-    disks_path = "/dev/disk/by-path/"
     disk_list = []
-    if not os.path.exists(disks_path):
-        return disk_list
-    for dev in os.listdir(disks_path):
-        if pci_address in dev:
-            link = os.readlink(os.path.join(disks_path, dev))
-            disk_list.append(os.path.abspath(os.path.join(disks_path, link)))
+    for device in os.listdir('/sys/block'):
+        if pci_address in os.path.realpath(os.path.join('/sys/block', device)):
+            disk_list.append('/dev/%s' % device)
     return disk_list
 
 
@@ -131,11 +127,14 @@ def get_interfaces_in_pci_address(pci_address, pci_class):
     :return: list of generic interfaces in a PCI address.
     """
     pci_class_path = "/sys/class/%s/" % pci_class
+    ifaces = []
     if not os.path.isdir(pci_class_path):
         raise ValueError("Please provide valid class name")
-    return [interface for interface in os.listdir(pci_class_path)
-            if pci_address in os.readlink(os.path.join(pci_class_path,
-                                                       interface))]
+    for interface in os.listdir(pci_class_path):
+        pci_path = os.path.join(pci_class_path, interface)
+        if os.path.isdir(pci_path) and pci_address in os.readlink(pci_path):
+            ifaces.append(interface)
+    return ifaces
 
 
 def get_pci_class_name(pci_address):
@@ -189,7 +188,7 @@ def get_slot_from_sysfs(full_pci_address):
     if not os.path.isfile('/sys/bus/pci/devices/%s/devspec' % full_pci_address):
         return
     devspec = genio.read_file("/sys/bus/pci/devices/%s/devspec"
-                              % full_pci_address)
+                              % full_pci_address).strip()
     if not os.path.isfile("/proc/device-tree/%s/ibm,loc-code" % devspec):
         return
     slot = genio.read_file("/proc/device-tree/%s/ibm,loc-code" % devspec)
