@@ -31,13 +31,10 @@ import threading
 import time
 from io import BytesIO, UnsupportedOperation
 
-from . import astring, path
-from .wait import wait_for
+from avocado.utils import astring, path
+from avocado.utils.wait import wait_for
 
-LOG = logging.getLogger('avocado.test')
-stdout_log = logging.getLogger('avocado.test.stdout')
-stderr_log = logging.getLogger('avocado.test.stderr')
-output_log = logging.getLogger('avocado.test.output')
+LOG = logging.getLogger(__name__)
 
 #: The active wrapper utility script.
 CURRENT_WRAPPER = None
@@ -59,17 +56,6 @@ WRAP_PROCESS_NAMES_EXPR = []
 #: undefined, this situation will be flagged by an exception.
 UNDEFINED_BEHAVIOR_EXCEPTION = None
 
-#: The current output record mode.  It's not possible to record
-#: both the 'stdout' and 'stderr' streams, and at the same time
-#: in the right order, the combined 'output' stream.  So this
-#: setting defines the mode.
-OUTPUT_CHECK_RECORD_MODE = None
-
-#: When using the nrunner architecture we don't need to log messages into the
-#: stream_logger as well. By setting this to True, we will set stream_logger to
-#: None.
-NRUNNER_MODE = True
-
 # variable=value bash assignment
 _RE_BASH_SET_VARIABLE = re.compile(r"[a-zA-Z]\w*=.*")
 
@@ -531,9 +517,8 @@ class SubProcess:
     Run a subprocess in the background, collecting stdout/stderr streams.
     """
 
-    def __init__(self, cmd, verbose=True, allow_output_check=None,
-                 shell=False, env=None, sudo=False,
-                 ignore_bg_processes=False, encoding=None):
+    def __init__(self, cmd, verbose=True, shell=False, env=None, sudo=False,
+                 ignore_bg_processes=False, encoding=None, logger=None):
         """
         Creates the subprocess object, stdout/err, reader threads and locks.
 
@@ -541,24 +526,6 @@ class SubProcess:
         :type cmd: str
         :param verbose: Whether to log the command run and stdout/stderr.
         :type verbose: bool
-        :param allow_output_check: Whether to record the output from this
-                                   process (from stdout and stderr) in the
-                                   test's output record files. Valid values:
-                                   'stdout', for standard output *only*,
-                                   'stderr' for standard error *only*,
-                                   'both' for both standard output and error
-                                   in separate files, 'combined' for
-                                   standard output and error in a single file,
-                                   and 'none' to disable all recording. 'all'
-                                   is also a valid, but deprecated, option that
-                                   is a synonym of 'both'.  If an explicit value
-                                   is not given to this parameter, that is, if
-                                   None is given, it defaults to using the module
-                                   level configuration, as set by
-                                   :data:`OUTPUT_CHECK_RECORD_MODE`.  If the
-                                   module level configuration itself is not set,
-                                   it defaults to 'none'.
-        :type allow_output_check: str
         :param shell: Whether to run the subprocess in a subshell.
         :type shell: bool
         :param env: Use extra environment variables.
@@ -581,6 +548,10 @@ class SubProcess:
                          of the command result stdout and stderr, by default
                          :data:`avocado.utils.astring.ENCODING`
         :type encoding: str
+        :param logger: User's custom logger, which will be logging the subprocess
+                       outputs. When this parameter is not set, the
+                       `avocado.utils.process` logger will be used.
+        :type logger: logging.Logger
         :raises: ValueError if incorrect values are given to parameters
         """
         if encoding is None:
@@ -590,16 +561,6 @@ class SubProcess:
         else:
             self.cmd = cmd
         self.verbose = verbose
-        if allow_output_check is None:
-            allow_output_check = OUTPUT_CHECK_RECORD_MODE
-        if allow_output_check is None:
-            allow_output_check = 'both'
-        if allow_output_check not in ('stdout', 'stderr', 'both',
-                                      'combined', 'none', 'all'):
-            msg = ("Invalid value (%s) set in allow_output_check" %
-                   allow_output_check)
-            raise ValueError(msg)
-        self.allow_output_check = allow_output_check
         self.result = CmdResult(self.cmd, encoding=encoding)
         self.shell = shell
         if env:
@@ -609,11 +570,14 @@ class SubProcess:
             self.env = None
         self._popen = None
 
+        self.logger = logger or LOG
+        self.stdout_logger = self.logger.getChild('stdout')
+        self.stderr_logger = self.logger.getChild('stderr')
+        self.output_logger = self.logger.getChild('output')
         # Drainers used when reading from the PIPEs and writing to
         # files and logs
         self._stdout_drainer = None
         self._stderr_drainer = None
-        self._combined_drainer = None
 
         self._ignore_bg_processes = ignore_bg_processes
 
@@ -653,82 +617,61 @@ class SubProcess:
         return cmd
 
     def _init_subprocess(self):
-        if self._popen is None:
+        def signal_handler(signum, frame):  # pylint: disable=W0613
+            self.result.interrupted = "signal/ctrl+c"
+            self.wait()
+            signal.default_int_handler()
+
+        if self._popen is not None:
+            return
+
+        if self.verbose:
+            LOG.info("Running '%s'", self.cmd)
+        if self.shell is False:
+            cmd = shlex.split(self.cmd)
+        else:
+            cmd = self.cmd
+        try:
+            self._popen = subprocess.Popen(cmd,
+                                           stdout=subprocess.PIPE,
+                                           stderr=subprocess.PIPE,
+                                           shell=self.shell,
+                                           env=self.env)
+        except OSError as details:
+            details.strerror += " (%s)" % self.cmd
+            raise details
+
+        self.start_time = time.monotonic()  # pylint: disable=W0201
+
+        # prepare fd drainers
+        self._stdout_drainer = FDDrainer(
+            self._popen.stdout.fileno(),
+            self.result,
+            name="%s-stdout" % self.cmd,
+            logger=self.logger,
+            logger_prefix="[stdout] %s",
+            stream_logger=None,
+            ignore_bg_processes=self._ignore_bg_processes,
+            verbose=self.verbose)
+        self._stderr_drainer = FDDrainer(
+            self._popen.stderr.fileno(),
+            self.result,
+            name="%s-stderr" % self.cmd,
+            logger=self.logger,
+            logger_prefix="[stderr] %s",
+            stream_logger=None,
+            ignore_bg_processes=self._ignore_bg_processes,
+            verbose=self.verbose)
+
+        # start stdout/stderr threads
+        self._stdout_drainer.start()
+        self._stderr_drainer.start()
+
+        try:
+            signal.signal(signal.SIGINT, signal_handler)
+        except ValueError:
             if self.verbose:
-                LOG.info("Running '%s'", self.cmd)
-            if self.shell is False:
-                cmd = shlex.split(self.cmd)
-            else:
-                cmd = self.cmd
-            try:
-                if self.allow_output_check == 'combined':
-                    stderr = subprocess.STDOUT
-                else:
-                    stderr = subprocess.PIPE
-                self._popen = subprocess.Popen(cmd,
-                                               stdout=subprocess.PIPE,
-                                               stderr=stderr,
-                                               shell=self.shell,
-                                               env=self.env)
-            except OSError as details:
-                details.strerror += " (%s)" % self.cmd
-                raise details
-
-            self.start_time = time.monotonic()  # pylint: disable=W0201
-
-            # prepare fd drainers
-            if self.allow_output_check == 'combined':
-                self._combined_drainer = FDDrainer(
-                    self._popen.stdout.fileno(),
-                    self.result,
-                    name="%s-combined" % self.cmd,
-                    logger=LOG,
-                    logger_prefix="[output] %s",
-                    # FIXME, in fact, a new log has to be used here
-                    stream_logger=output_log,
-                    ignore_bg_processes=self._ignore_bg_processes,
-                    verbose=self.verbose)
-                self._combined_drainer.start()
-
-            else:
-                if self.allow_output_check == 'none' or NRUNNER_MODE:
-                    stdout_stream_logger = None
-                    stderr_stream_logger = None
-                else:
-                    stdout_stream_logger = stdout_log
-                    stderr_stream_logger = stderr_log
-                self._stdout_drainer = FDDrainer(
-                    self._popen.stdout.fileno(),
-                    self.result,
-                    name="%s-stdout" % self.cmd,
-                    logger=LOG,
-                    logger_prefix="[stdout] %s",
-                    stream_logger=stdout_stream_logger,
-                    ignore_bg_processes=self._ignore_bg_processes,
-                    verbose=self.verbose)
-                self._stderr_drainer = FDDrainer(
-                    self._popen.stderr.fileno(),
-                    self.result,
-                    name="%s-stderr" % self.cmd,
-                    logger=LOG,
-                    logger_prefix="[stderr] %s",
-                    stream_logger=stderr_stream_logger,
-                    ignore_bg_processes=self._ignore_bg_processes,
-                    verbose=self.verbose)
-
-                # start stdout/stderr threads
-                self._stdout_drainer.start()
-                self._stderr_drainer.start()
-
-            def signal_handler(signum, frame):  # pylint: disable=W0613
-                self.result.interrupted = "signal/ctrl+c"
-                self.wait()
-                signal.default_int_handler()
-            try:
-                signal.signal(signal.SIGINT, signal_handler)
-            except ValueError:
-                if self.verbose:
-                    LOG.info("Command %s running on a thread", self.cmd)
+                LOG.info("Command %s running on a thread", self.cmd)
 
     def _fill_results(self, rc):
         self._init_subprocess()
@@ -746,8 +689,6 @@ class SubProcess:
         Close subprocess stdout and stderr, and put values into result obj.
         """
         # Cleaning up threads
-        if self._combined_drainer is not None:
-            self._combined_drainer.flush()
         if self._stdout_drainer is not None:
             self._stdout_drainer.flush()
         if self._stderr_drainer is not None:
@@ -777,8 +718,6 @@ class SubProcess:
         :rtype: str
         """
         self._init_subprocess()
-        if self._combined_drainer is not None:
-            return self._combined_drainer.data.getvalue()
         return self._stdout_drainer.data.getvalue()
 
     def get_stderr(self):
@@ -789,8 +728,6 @@ class SubProcess:
         :rtype: str
         """
         self._init_subprocess()
-        if self._combined_drainer is not None:
-            return ''
         return self._stderr_drainer.data.getvalue()
 
     def terminate(self):
@@ -970,9 +907,8 @@ class WrapSubProcess(SubProcess):
     """
 
     def __init__(self, cmd, verbose=True,
-                 allow_output_check=None,
                  shell=False, env=None, wrapper=None, sudo=False,
-                 ignore_bg_processes=False, encoding=None):
+                 ignore_bg_processes=False, encoding=None, logger=None):
         if wrapper is None and CURRENT_WRAPPER is not None:
             wrapper = CURRENT_WRAPPER
         self.wrapper = wrapper
@@ -980,9 +916,10 @@ class WrapSubProcess(SubProcess):
             if not os.path.exists(self.wrapper):
                 raise IOError("No such wrapper: '%s'" % self.wrapper)
             cmd = wrapper + ' ' + cmd
-        super(WrapSubProcess, self).__init__(cmd, verbose, allow_output_check,
+        super(WrapSubProcess, self).__init__(cmd, verbose,
                                              shell, env, sudo,
-                                             ignore_bg_processes, encoding)
+                                             ignore_bg_processes, encoding,
+                                             logger)
 
 
 def should_run_inside_wrapper(cmd):
@@ -1024,9 +961,8 @@ def get_sub_process_klass(cmd):
 
 
 def run(cmd, timeout=None, verbose=True, ignore_status=False,
-        allow_output_check=None, shell=False,
-        env=None, sudo=False, ignore_bg_processes=False,
-        encoding=None):
+        shell=False, env=None, sudo=False, ignore_bg_processes=False,
+        encoding=None, logger=None):
     """
     Run a subprocess, returning a CmdResult object.
 
@@ -1042,24 +978,6 @@ def run(cmd, timeout=None, verbose=True, ignore_status=False,
     :param ignore_status: Whether to raise an exception when command returns
                           =! 0 (False), or not (True).
     :type ignore_status: bool
-    :param allow_output_check: Whether to record the output from this
-                               process (from stdout and stderr) in the
-                               test's output record files. Valid values:
-                               'stdout', for standard output *only*,
-                               'stderr' for standard error *only*,
-                               'both' for both standard output and error
-                               in separate files, 'combined' for
-                               standard output and error in a single file,
-                               and 'none' to disable all recording. 'all'
-                               is also a valid, but deprecated, option that
-                               is a synonym of 'both'.  If an explicit value
-                               is not given to this parameter, that is, if
-                               None is given, it defaults to using the module
-                               level configuration, as set by
-                               :data:`OUTPUT_CHECK_RECORD_MODE`.  If the
-                               module level configuration itself is not set,
-                               it defaults to 'none'.
-    :type allow_output_check: str
     :param shell: Whether to run the command on a subshell
     :type shell: bool
     :param env: Use extra environment variables
@@ -1074,6 +992,10 @@ def run(cmd, timeout=None, verbose=True, ignore_status=False,
                      of the command result stdout and stderr, by default
                      :data:`avocado.utils.astring.ENCODING`
     :type encoding: str
+    :param logger: User's custom logger, which will be logging the subprocess
+                   outputs. When this parameter is not set, the
+                   `avocado.utils.process` logger will be used.
+    :type logger: logging.Logger
 
     :return: An :class:`CmdResult` object.
     :raise: :class:`CmdError`, if ``ignore_status=False``.
@@ -1084,9 +1006,9 @@ def run(cmd, timeout=None, verbose=True, ignore_status=False,
         encoding = astring.ENCODING
     klass = get_sub_process_klass(cmd)
     sp = klass(cmd=cmd, verbose=verbose,
-               allow_output_check=allow_output_check, shell=shell, env=env,
+               shell=shell, env=env,
                sudo=sudo, ignore_bg_processes=ignore_bg_processes,
-               encoding=encoding)
+               encoding=encoding, logger=logger)
     cmd_result = sp.run(timeout=timeout)
     fail_condition = cmd_result.exit_status != 0 or cmd_result.interrupted
     if fail_condition and not ignore_status:
@@ -1095,9 +1017,8 @@ def run(cmd, timeout=None, verbose=True, ignore_status=False,
 
 
 def system(cmd, timeout=None, verbose=True, ignore_status=False,
-           allow_output_check=None, shell=False,
-           env=None, sudo=False, ignore_bg_processes=False,
-           encoding=None):
+           shell=False, env=None, sudo=False, ignore_bg_processes=False,
+           encoding=None, logger=None):
     """
     Run a subprocess, returning its exit code.
 
@@ -1113,24 +1034,6 @@ def system(cmd, timeout=None, verbose=True, ignore_status=False,
     :param ignore_status: Whether to raise an exception when command returns
                           =! 0 (False), or not (True).
     :type ignore_status: bool
-    :param allow_output_check: Whether to record the output from this
-                               process (from stdout and stderr) in the
-                               test's output record files. Valid values:
-                               'stdout', for standard output *only*,
-                               'stderr' for standard error *only*,
-                               'both' for both standard output and error
-                               in separate files, 'combined' for
-                               standard output and error in a single file,
-                               and 'none' to disable all recording. 'all'
-                               is also a valid, but deprecated, option that
-                               is a synonym of 'both'.  If an explicit value
-                               is not given to this parameter, that is, if
-                               None is given, it defaults to using the module
-                               level configuration, as set by
-                               :data:`OUTPUT_CHECK_RECORD_MODE`.  If the
-                               module level configuration itself is not set,
-                               it defaults to 'none'.
-    :type allow_output_check: str
     :param shell: Whether to run the command on a subshell
     :type shell: bool
     :param env: Use extra environment variables.
@@ -1145,22 +1048,24 @@ def system(cmd, timeout=None, verbose=True, ignore_status=False,
                      of the command result stdout and stderr, by default
                      :data:`avocado.utils.astring.ENCODING`
     :type encoding: str
+    :param logger: User's custom logger, which will be logging the subprocess
+                   outputs. When this parameter is not set, the
+                   `avocado.utils.process` logger will be used.
+    :type logger: logging.Logger
 
     :return: Exit code.
     :rtype: int
     :raise: :class:`CmdError`, if ``ignore_status=False``.
     """
     cmd_result = run(cmd=cmd, timeout=timeout, verbose=verbose, ignore_status=ignore_status,
-                     allow_output_check=allow_output_check, shell=shell, env=env,
-                     sudo=sudo, ignore_bg_processes=ignore_bg_processes,
-                     encoding=encoding)
+                     shell=shell, env=env, sudo=sudo, ignore_bg_processes=ignore_bg_processes,
+                     encoding=encoding, logger=logger)
     return cmd_result.exit_status
 
 
 def system_output(cmd, timeout=None, verbose=True, ignore_status=False,
-                  allow_output_check=None, shell=False,
-                  env=None, sudo=False, ignore_bg_processes=False,
-                  strip_trail_nl=True, encoding=None):
+                  shell=False, env=None, sudo=False, ignore_bg_processes=False,
+                  strip_trail_nl=True, encoding=None, logger=None):
     """
     Run a subprocess, returning its output.
 
@@ -1175,24 +1080,6 @@ def system_output(cmd, timeout=None, verbose=True, ignore_status=False,
     :type verbose: bool
     :param ignore_status: Whether to raise an exception when command returns
                           =! 0 (False), or not (True).
-    :param allow_output_check: Whether to record the output from this
-                               process (from stdout and stderr) in the
-                               test's output record files. Valid values:
-                               'stdout', for standard output *only*,
-                               'stderr' for standard error *only*,
-                               'both' for both standard output and error
-                               in separate files, 'combined' for
-                               standard output and error in a single file,
-                               and 'none' to disable all recording. 'all'
-                               is also a valid, but deprecated, option that
-                               is a synonym of 'both'.  If an explicit value
-                               is not given to this parameter, that is, if
-                               None is given, it defaults to using the module
-                               level configuration, as set by
-                               :data:`OUTPUT_CHECK_RECORD_MODE`.  If the
-                               module level configuration itself is not set,
-                               it defaults to 'none'.
-    :type allow_output_check: str
     :param shell: Whether to run the command on a subshell
     :type shell: bool
     :param env: Use extra environment variables
@@ -1212,23 +1099,26 @@ def system_output(cmd, timeout=None, verbose=True, ignore_status=False,
                      of the command result stdout and stderr, by default
                      :data:`avocado.utils.astring.ENCODING`
     :type encoding: str
+    :param logger: User's custom logger, which will be logging the subprocess
+                   outputs. When this parameter is not set, the
+                   `avocado.utils.process` logger will be used.
+    :type logger: logging.Logger
 
     :return: Command output.
     :rtype: bytes
     :raise: :class:`CmdError`, if ``ignore_status=False``.
     """
     cmd_result = run(cmd=cmd, timeout=timeout, verbose=verbose, ignore_status=ignore_status,
-                     allow_output_check=allow_output_check, shell=shell, env=env,
-                     sudo=sudo, ignore_bg_processes=ignore_bg_processes,
-                     encoding=encoding)
+                     shell=shell, env=env, sudo=sudo, ignore_bg_processes=ignore_bg_processes,
+                     encoding=encoding, logger=logger)
     if strip_trail_nl:
         return cmd_result.stdout.rstrip(b'\n\r')
     return cmd_result.stdout
 
 
 def getoutput(cmd, timeout=None, verbose=False, ignore_status=True,
-              allow_output_check='combined', shell=True,
-              env=None, sudo=False, ignore_bg_processes=False):
+              shell=True, env=None, sudo=False, ignore_bg_processes=False,
+              logger=None):
     """
     Because commands module is removed in Python3 and it redirect stderr
     to stdout, we port commands.getoutput to make code compatible
@@ -1245,24 +1135,6 @@ def getoutput(cmd, timeout=None, verbose=False, ignore_status=True,
     :type verbose: bool
     :param ignore_status: Whether to raise an exception when command returns
                           =! 0 (False), or not (True).
-    :param allow_output_check: Whether to record the output from this
-                               process (from stdout and stderr) in the
-                               test's output record files. Valid values:
-                               'stdout', for standard output *only*,
-                               'stderr' for standard error *only*,
-                               'both' for both standard output and error
-                               in separate files, 'combined' for
-                               standard output and error in a single file,
-                               and 'none' to disable all recording. 'all'
-                               is also a valid, but deprecated, option that
-                               is a synonym of 'both'.  If an explicit value
-                               is not given to this parameter, that is, if
-                               None is given, it defaults to using the module
-                               level configuration, as set by
-                               :data:`OUTPUT_CHECK_RECORD_MODE`.  If the
-                               module level configuration itself is not set,
-                               it defaults to 'none'.
-    :type allow_output_check: str
     :param shell: Whether to run the command on a subshell
     :type shell: bool
     :param env: Use extra environment variables
@@ -1276,19 +1148,25 @@ def getoutput(cmd, timeout=None, verbose=False, ignore_status=True,
     :type sudo: bool
     :param ignore_bg_processes: Whether to ignore background processes
     :type ignore_bg_processes: bool
+    :param logger: User's custom logger, which will be logging the subprocess
+                   outputs. When this parameter is not set, the
+                   `avocado.utils.process` logger will be used.
+    :type logger: logging.Logger
 
     :return: Command output(stdout or stderr).
     :rtype: str
     """
     return getstatusoutput(cmd=cmd, timeout=timeout, verbose=verbose,
                            ignore_status=ignore_status,
-                           allow_output_check=allow_output_check, shell=shell, env=env,
-                           sudo=sudo, ignore_bg_processes=ignore_bg_processes)[1]
+                           shell=shell,
+                           env=env, sudo=sudo,
+                           ignore_bg_processes=ignore_bg_processes,
+                           logger=logger)[1]
 
 
 def getstatusoutput(cmd, timeout=None, verbose=False, ignore_status=True,
-                    allow_output_check='combined', shell=True,
-                    env=None, sudo=False, ignore_bg_processes=False):
+                    shell=True, env=None, sudo=False,
+                    ignore_bg_processes=False, logger=None):
     """
     Because commands module is removed in Python3 and it redirect stderr
     to stdout, we port commands.getstatusoutput to make code compatible
@@ -1305,24 +1183,6 @@ def getstatusoutput(cmd, timeout=None, verbose=False, ignore_status=True,
     :type verbose: bool
     :param ignore_status: Whether to raise an exception when command returns
                           =! 0 (False), or not (True).
-    :param allow_output_check: Whether to record the output from this
-                               process (from stdout and stderr) in the
-                               test's output record files. Valid values:
-                               'stdout', for standard output *only*,
-                               'stderr' for standard error *only*,
-                               'both' for both standard output and error
-                               in separate files, 'combined' for
-                               standard output and error in a single file,
-                               and 'none' to disable all recording. 'all'
-                               is also a valid, but deprecated, option that
-                               is a synonym of 'both'.  If an explicit value
-                               is not given to this parameter, that is, if
-                               None is given, it defaults to using the module
-                               level configuration, as set by
-                               :data:`OUTPUT_CHECK_RECORD_MODE`.  If the
-                               module level configuration itself is not set,
-                               it defaults to 'none'.
-    :type allow_output_check: str
     :param shell: Whether to run the command on a subshell
     :type shell: bool
     :param env: Use extra environment variables
@@ -1336,13 +1196,18 @@ def getstatusoutput(cmd, timeout=None, verbose=False, ignore_status=True,
     :type sudo: bool
     :param ignore_bg_processes: Whether to ignore background processes
     :type ignore_bg_processes: bool
+    :param logger: User's custom logger, which will be logging the subprocess
+                   outputs. When this parameter is not set, the
+                   `avocado.utils.process` logger will be used.
+    :type logger: logging.Logger
 
     :return: Exit status and command output(stdout and stderr).
     :rtype: tuple
     """
-    cmd_result = run(cmd=cmd, timeout=timeout, verbose=verbose, ignore_status=ignore_status,
-                     allow_output_check=allow_output_check, shell=shell, env=env,
-                     sudo=sudo, ignore_bg_processes=ignore_bg_processes)
+    cmd_result = run(cmd=cmd, timeout=timeout, verbose=verbose,
+                     ignore_status=ignore_status,
+                     shell=shell, env=env, sudo=sudo,
+                     ignore_bg_processes=ignore_bg_processes, logger=logger)
     text = cmd_result.stdout_text
     sts = cmd_result.exit_status
     if text[-1:] == '\n':
