@@ -26,9 +26,9 @@ import os
 import re
 from tempfile import mkstemp
 
-from . import process
+from avocado.utils import process
 
-LOG = logging.getLogger('avocado.test')
+LOG = logging.getLogger(__name__)
 
 _COMMAND_TABLE_DOC = """
 Taken from http://fedoraproject.org/wiki/SysVinit_to_Systemd_Cheatsheet
