@@ -6,8 +6,6 @@ from avocado.core.job import Job
 from avocado.core.nrunner import Runnable
 from avocado.core.suite import TestSuite
 
-config = {'run.test_runner': 'nrunner'}
-
 # an exec-test runnable consists of a runnable type (exec-test),
 # an uri (examples/tests/sleeptest.sh), followed by zero to n arguments
 # ending with zero to m keyword arguments.
@@ -24,7 +22,7 @@ echo = Runnable('exec-test', '/usr/bin/echo', 'Hello World!')
 # the execution of examples/tests/sleeptest.sh takes around 2 seconds
 # and the output of the /usr/bin/echo test is available at the
 # job-results/latest/test-results/exec-test-2-_usr_bin_echo/stdout file.
-suite = TestSuite(config=config, tests=[sleeptest, echo], name="exec-test")
+suite = TestSuite(name="exec-test", tests=[sleeptest, echo])
 
-with Job(config, [suite]) as j:
+with Job(test_suites=[suite]) as j:
     sys.exit(j.run())
