@@ -5,6 +5,7 @@ import glob
 import multiprocessing
 import os
 import platform
+import re
 import sys
 
 from avocado import Test
@@ -13,9 +14,6 @@ from avocado.core.job import Job
 from avocado.core.suite import TestSuite
 from selftests.utils import python_module_available
 
-BOOLEAN_ENABLED = [True, 'true', 'on', 1]
-BOOLEAN_DISABLED = [False, 'false', 'off', 0]
-
 
 class JobAPIFeaturesTest(Test):
 
@@ -42,7 +40,8 @@ class JobAPIFeaturesTest(Test):
         """Check if `content` exists or not in a file."""
         content = self.params.get('content')
         assert_func = self.get_assert_function()
-        assert_func(self.file_has_content(file_path, content))
+        regex = self.params.get('regex', default=False)
+        assert_func(self.file_has_content(file_path, content, regex))
 
     def create_config(self, value=None):
         """Creates the Job config."""
@@ -51,20 +50,28 @@ class JobAPIFeaturesTest(Test):
         reference = self.params.get('reference', default=['/bin/true'])
         config = {'core.show': ['none'],
                   'run.results_dir': self.workdir,
-                  'run.references': reference}
+                  'resolver.references': reference}
         namespace = self.params.get('namespace')
         config[namespace] = value
+        extra_job_config = self.params.get('extra_job_config')
+        if extra_job_config is not None:
+            config.update(extra_job_config)
 
         return config
 
     @staticmethod
-    def file_has_content(file_path, content):
+    def file_has_content(file_path, content, regex):
         """Check if a file has `content`."""
         if os.path.isfile(file_path):
             with open(file_path, "r") as f:
-                source_content = f.read()
-            if content in source_content:
-                return True
+                lines = f.readlines()
+            for line in lines:
+                if regex:
+                    if re.match(content, line):
+                        return True
+                else:
+                    if content in line:
+                        return True
         return False
 
     def get_assert_function(self):
@@ -82,7 +89,7 @@ class JobAPIFeaturesTest(Test):
         """Run a Job"""
         config = self.create_config()
 
-        suite = TestSuite.from_config(config)
+        suite = TestSuite.from_config(config, '')
 
         # run the job
         with Job(config, [suite]) as j:
@@ -190,54 +197,53 @@ class JobAPIFeaturesTest(Test):
 
 
 def parse_args():
-    parser = argparse.ArgumentParser()
+    parser = argparse.ArgumentParser(
+        formatter_class=argparse.RawDescriptionHelpFormatter,
+        epilog='''\
+The list of test availables for --skip and --select are:
+
+  static-checks      Run static checks (isort, lint, etc)
+  job-api            Run job API checks
+  nrunner-interface  Run selftests/functional/test_nrunner_interface.py
+  unit               Run selftests/unit/
+  jobs               Run selftests/jobs/
+  functional         Run selftests/functional/
+  optional-plugins   Run optional_plugins/*/tests/
+        ''')
+    group = parser.add_mutually_exclusive_group()
     parser.add_argument('-f',
                         '--list-features',
                         help='show the list of features tested by this test.',
                         action='store_true')
-    parser.add_argument('--static-checks',
-                        help='Run static checks (isort, lint, etc)',
-                        action='store_true')
-    parser.add_argument('--job-api',
-                        help='Run job API checks',
-                        action='store_true')
-    parser.add_argument('--nrunner-interface',
-                        help='Run selftests/functional/test_nrunner_interface.py',
-                        action='store_true')
-    parser.add_argument('--unit',
-                        help='Run selftests/unit/',
-                        action='store_true')
-    parser.add_argument('--jobs',
-                        help='Run selftests/jobs/',
-                        action='store_true')
-    parser.add_argument('--functional',
-                        help='Run selftests/functional/',
-                        action='store_true')
-    parser.add_argument('--optional-plugins',
-                        help='Run optional_plugins/*/tests/',
-                        action='store_true')
+    group.add_argument('--skip',
+                       help='Run all tests and skip listed tests',
+                       action='append', default=[])
+    group.add_argument('--select',
+                       help='Do not run any test, only these listed after',
+                       action='append', default=[])
+    # Hidden argument to have the list of tests
+    group.add_argument('--dict-tests',
+                       default={}, help=argparse.SUPPRESS)
     parser.add_argument('--disable-plugin-checks',
                         help='Disable checks for one or more plugins (by directory name), separated by comma',
                         action='append', default=[])
 
     arg = parser.parse_args()
-    # Make a list of strings instead of a list with a single string
-    if len(arg.disable_plugin_checks) > 0:
-        arg.disable_plugin_checks = arg.disable_plugin_checks[0].split(",")
     return arg
 
 
 def create_suite_job_api(args):  # pylint: disable=W0621
-    test_class = 'JobAPIFeaturesTest'
     suites = []
 
+    def get_ref(method_short_name):
+        return ['%s:JobAPIFeaturesTest.test_%s' % (__file__, method_short_name)]
+
     # ========================================================================
     # Test if the archive file was created
     # ========================================================================
-    check_archive_file_exists = ('%s:%s.test_check_archive_file_exists'
-                                 % (__file__, test_class))
     config_check_archive_file_exists = {
-        'run.references': [check_archive_file_exists],
+        'resolver.references': get_ref('check_archive_file_exists'),
+        'run.dict_variants.variant_id_keys': ['namespace', 'value'],
         'run.dict_variants': [
             {'namespace': 'run.results.archive',
              'value': True,
@@ -251,11 +257,9 @@ def create_suite_job_api(args):  # pylint: disable=W0621
     # ========================================================================
     # Test if the category directory was created
     # ========================================================================
-    check_category_directory_exists = (
-        '%s:%s.test_check_category_directory_exists'
-        % (__file__, test_class))
     config_check_category_directory_exists = {
-        'run.references': [check_category_directory_exists],
+        'resolver.references': get_ref('check_category_directory_exists'),
+        'run.dict_variants.variant_id_keys': ['namespace', 'value'],
         'run.dict_variants': [
             {'namespace': 'run.job_category',
              'value': 'foo',
@@ -269,10 +273,9 @@ def create_suite_job_api(args):  # pylint: disable=W0621
     # ========================================================================
     # Test if a directory was created
     # ========================================================================
-    check_directory_exists = ('%s:%s.test_check_directory_exists'
-                              % (__file__, test_class))
     config_check_directory_exists = {
-        'run.references': [check_directory_exists],
+        'resolver.references': get_ref('check_directory_exists'),
+        'run.dict_variants.variant_id_keys': ['namespace', 'value'],
         'run.dict_variants': [
              {'namespace': 'sysinfo.collect.enabled',
               'value': True,
@@ -292,10 +295,9 @@ def create_suite_job_api(args):  # pylint: disable=W0621
     # ========================================================================
     # Test the content of a file
     # ========================================================================
-    check_file_content = ('%s:%s.test_check_file_content'
-                          % (__file__, test_class))
     config_check_file_content = {
-        'run.references': [check_file_content],
+        'resolver.references': get_ref('check_file_content'),
+        'run.dict_variants.variant_id_keys': ['namespace', 'value', 'file'],
         'run.dict_variants': [
             # finding the correct 'content' here is trick because any
             # simple string is added to the variant file name and is
@@ -305,13 +307,15 @@ def create_suite_job_api(args):  # pylint: disable=W0621
             {'namespace': 'job.output.loglevel',
              'value': 'INFO',
              'file': 'job.log',
-             'content': 'DEBUG| Test metadata',
-             'assert': False},
+             'content': r'DEBUG\| Test metadata:$',
+             'assert': False,
+             'regex': True},
 
             {'namespace': 'job.run.result.tap.include_logs',
              'value': True,
              'file': 'results.tap',
-             'content': "Command '/bin/true' finished with 0",
+             'reference': ['examples/tests/passtest.py:PassTest.test'],
+             'content': 'PASS 1-examples/tests/passtest.py:PassTest.test',
              'assert': True},
 
             {'namespace': 'job.run.result.tap.include_logs',
@@ -331,7 +335,7 @@ def create_suite_job_api(args):  # pylint: disable=W0621
              'file': 'results.xml',
              'content': '--[ CUT DUE TO XML PER TEST LIMIT ]--',
              'assert': True,
-             'reference': ['/bin/false'],
+             'reference': ['examples/tests/failtest.py:FailTest.test'],
              'exit_code': 1},
 
             {'namespace': 'run.failfast',
@@ -340,7 +344,8 @@ def create_suite_job_api(args):  # pylint: disable=W0621
              'content': '"skip": 1',
              'assert': True,
              'reference': ['/bin/false', '/bin/true'],
-             'exit_code': 9},
+             'exit_code': 9,
+             'extra_job_config': {'nrunner.max_parallel_tasks': 1}},
 
             {'namespace': 'run.ignore_missing_references',
              'value': 'on',
@@ -371,10 +376,9 @@ def create_suite_job_api(args):  # pylint: disable=W0621
     # ========================================================================
     # Test if the result file was created
     # ========================================================================
-    check_file_exists = ('%s:%s.test_check_file_exists'
-                         % (__file__, test_class))
     config_check_file_exists = {
-        'run.references': [check_file_exists],
+        'resolver.references': get_ref('check_file_exists'),
+        'run.dict_variants.variant_id_keys': ['namespace', 'value'],
         'run.dict_variants': [
             {'namespace': 'job.run.result.json.enabled',
              'value': True,
@@ -450,10 +454,9 @@ def create_suite_job_api(args):  # pylint: disable=W0621
     # ========================================================================
     # Test if a file was created
     # ========================================================================
-    check_output_file = ('%s:%s.test_check_output_file'
-                         % (__file__, test_class))
     config_check_output_file = {
-        'run.references': [check_output_file],
+        'resolver.references': get_ref('check_output_file'),
+        'run.dict_variants.variant_id_keys': ['namespace', 'file'],
         'run.dict_variants': [
             {'namespace': 'job.run.result.json.output',
              'file': 'custom.json',
@@ -484,10 +487,9 @@ def create_suite_job_api(args):  # pylint: disable=W0621
     # ========================================================================
     # Test if the temporary directory was created
     # ========================================================================
-    check_tmp_directory_exists = ('%s:%s.test_check_tmp_directory_exists'
-                                  % (__file__, test_class))
     config_check_tmp_directory_exists = {
-        'run.references': [check_tmp_directory_exists],
+        'resolver.references': get_ref('check_tmp_directory_exists'),
+        'run.dict_variants.variant_id_keys': ['namespace', 'value'],
         'run.dict_variants': [
             {'namespace': 'run.keep_tmp',
              'value': True,
@@ -506,60 +508,89 @@ def create_suites(args):  # pylint: disable=W0621
     # Run nrunner interface checks for all available runners
     # ========================================================================
     config_nrunner_interface = {
-        'run.references': ['selftests/functional/test_nrunner_interface.py'],
+        'resolver.references': ['selftests/functional/test_nrunner_interface.py'],
+        'run.dict_variants.variant_id_keys': ['runner'],
         'run.dict_variants': [
-            {'runner': 'avocado-runner'},
-            {'runner': 'avocado-runner-noop'},
-            {'runner': 'avocado-runner-exec-test'},
-            {'runner': 'avocado-runner-python-unittest'},
-            {'runner': 'avocado-runner-avocado-instrumented'},
-            {'runner': 'avocado-runner-tap'},
+            {'runner': 'avocado-runner',
+             'runnable-run-no-args-exit-code': 2,
+             'runnable-run-uri-only-exit-code': 2},
+
+            {'runner': 'avocado-runner-dry-run',
+             'runnable-run-no-args-exit-code': 0,
+             'runnable-run-uri-only-exit-code': 0},
+
+            {'runner': 'avocado-runner-noop',
+             'runnable-run-no-args-exit-code': 0,
+             'runnable-run-uri-only-exit-code': 0},
+
+            {'runner': 'avocado-runner-exec-test',
+             'runnable-run-no-args-exit-code': 0,
+             'runnable-run-uri-only-exit-code': 0},
+
+            {'runner': 'avocado-runner-python-unittest',
+             'runnable-run-no-args-exit-code': 0,
+             'runnable-run-uri-only-exit-code': 0},
+
+            {'runner': 'avocado-runner-avocado-instrumented',
+             'runnable-run-no-args-exit-code': 0,
+             'runnable-run-uri-only-exit-code': 0},
+
+            {'runner': 'avocado-runner-tap',
+             'runnable-run-no-args-exit-code': 0,
+             'runnable-run-uri-only-exit-code': 0},
         ]
     }
 
     if (python_module_available('avocado-framework-plugin-golang') and
             'golang' not in args.disable_plugin_checks):
         config_nrunner_interface['run.dict_variants'].append({
-            'runner': 'avocado-runner-golang'})
+            'runner': 'avocado-runner-golang',
+            'runnable-run-no-args-exit-code': 0,
+            'runnable-run-uri-only-exit-code': 0})
 
     if (python_module_available('avocado-framework-plugin-robot') and
             'robot' not in args.disable_plugin_checks):
         config_nrunner_interface['run.dict_variants'].append({
-            'runner': 'avocado-runner-robot'})
+            'runner': 'avocado-runner-robot',
+            'runnable-run-no-args-exit-code': 0,
+            'runnable-run-uri-only-exit-code': 0})
 
-    if args.nrunner_interface:
+    if args.dict_tests['nrunner-interface']:
         suites.append(TestSuite.from_config(config_nrunner_interface, "nrunner-interface"))
 
     # ========================================================================
     # Run all static checks, unit and functional tests
     # ========================================================================
 
-    selftests = []
-    if args.unit:
-        selftests.append('selftests/unit/')
-    if args.jobs:
-        selftests.append('selftests/jobs/')
-    if args.functional:
-        selftests.append('selftests/functional/')
-
     config_check = {
-        'run.references': selftests,
-        'run.test_runner': 'nrunner',
         'run.ignore_missing_references': True,
-        'job.output.testlogs.statuses': ['FAIL']
     }
 
-    if args.static_checks:
-        config_check['run.references'] += glob.glob('selftests/*.sh')
+    if args.dict_tests['unit']:
+        config_check['resolver.references'] = ['selftests/unit/']
+        suites.append(TestSuite.from_config(config_check, "unit"))
 
-    if args.optional_plugins:
+    if args.dict_tests['jobs']:
+        config_check['resolver.references'] = ['selftests/jobs/']
+        suites.append(TestSuite.from_config(config_check, "jobs"))
+
+    if args.dict_tests['functional']:
+        config_check['resolver.references'] = ['selftests/functional/']
+        suites.append(TestSuite.from_config(config_check, "functional"))
+
+    if args.dict_tests['static-checks']:
+        config_check['resolver.references'] = glob.glob('selftests/*.sh')
+        suites.append(TestSuite.from_config(config_check, "static-checks"))
+
+    if args.dict_tests['optional-plugins']:
+        config_check['resolver.references'] = []
         for optional_plugin in glob.glob('optional_plugins/*'):
             plugin_name = os.path.basename(optional_plugin)
             if plugin_name not in args.disable_plugin_checks:
                 pattern = '%s/tests/*' % optional_plugin
-                config_check['run.references'] += glob.glob(pattern)
+                config_check['resolver.references'] += glob.glob(pattern)
 
-    suites.append(TestSuite.from_config(config_check, "check"))
+        suites.append(TestSuite.from_config(config_check, "optional-plugins"))
 
     return suites
 
@@ -571,33 +602,30 @@ def print_failed_tests(tests):
             print(test.get('name'), test.get('status'))
 
 
-def enable_all_tests(args):   # pylint: disable=W0621
-    args.static_checks = True
-    args.job_api = True
-    args.nrunner_interface = True
-    args.unit = True
-    args.jobs = True
-    args.functional = True
-    args.optional_plugins = True
-
-
 def main(args):  # pylint: disable=W0621
 
-    if not any([args.static_checks, args.job_api, args.nrunner_interface,
-                args.unit, args.jobs, args.functional,
-                args.optional_plugins, args.list_features]):
-        print("No test were selected to run, running all of them.")
-        enable_all_tests(args)
+    args.dict_tests = {
+        'static-checks': False,
+        'job-api': False,
+        'nrunner-interface': False,
+        'unit': False,
+        'jobs': False,
+        'functional': False,
+        'optional-plugins': False,
+        }
 
-    suites = []
-    if args.job_api:
-        suites += create_suite_job_api(args)
-    suites += create_suites(args)
+    # Make a list of strings instead of a list with a single string
+    if len(args.disable_plugin_checks) > 0:
+        args.disable_plugin_checks = args.disable_plugin_checks[0].split(",")
+    if len(args.select) > 0:
+        args.select = args.select[0].split(",")
+    if len(args.skip) > 0:
+        args.skip = args.skip[0].split(",")
 
-    # ========================================================================
     # Print features covered in this test
-    # ========================================================================
     if args.list_features:
+        suites = create_suite_job_api(args)
+        suites += create_suites(args)
         features = []
         for suite in suites:
             for variants in suite.config['run.dict_variants']:
@@ -609,17 +637,52 @@ def main(args):  # pylint: disable=W0621
         print('\n'.join(unique_features))
         exit(0)
 
+    # Will only run the test you select, --select must be followed by list of tests
+    elif args.select:
+        for elem in args.select:
+            if elem not in args.dict_tests.keys():
+                print(elem, "is not in the list of valid tests.")
+                exit(0)
+            else:
+                args.dict_tests[elem] = True
+
+    # Will run all the tests except these you skip, --skip must be followed by list of tests
+    elif args.skip:
+        # Make all the values True, so later we set to False the tests we don't want to run
+        args.dict_tests = {x: True for x in args.dict_tests}
+
+        for elem in args.skip:
+            if elem not in args.dict_tests.keys():
+                print(elem, "is not in the list of valid tests.")
+                exit(0)
+            else:
+                args.dict_tests[elem] = False
+
+    # If no option was selected, run all tests!
+    elif not (args.skip or args.select):
+        print("No test were selected to run, running all of them.")
+        args.dict_tests = {x: True for x in args.dict_tests}
+
+    else:
+        print("Something went wrong, please report a bug!")
+        exit(1)
+
+    suites = []
+    if args.dict_tests['job-api']:
+        suites += create_suite_job_api(args)
+    suites += create_suites(args)
+
     # ========================================================================
     # Job execution
     # ========================================================================
-    config = {'core.show': ['app'],
-              'run.test_runner': 'nrunner'}
+    config = {'run.job_category': 'avocado-selftests',
+              'job.output.testlogs.statuses': ['FAIL', 'ERROR', 'INTERRUPT']}
 
     # Workaround for travis problem on arm64 - https://github.com/avocado-framework/avocado/issues/4768
     if (platform.machine() == 'aarch64'):
         max_parallel = int(multiprocessing.cpu_count()/2)
         for suite in suites:
-            if suite.name == 'check':
+            if suite.name == 'functional':
                 suite.config['nrunner.max_parallel_tasks'] = max_parallel
 
     with Job(config, suites) as j:
