@@ -9,7 +9,7 @@ import unittest
 from avocado.core import exit_codes
 from avocado.utils import process, script
 from selftests.utils import (AVOCADO, BASEDIR, TestCaseTmpDir,
-                             skipOnLevelsInferiorThan, skipUnlessPathExists)
+                             skipOnLevelsInferiorThan)
 
 AVOCADO_TEST_OK = """#!/usr/bin/env python
 from avocado import Test
@@ -305,32 +305,6 @@ class LoaderTestFunctional(TestCaseTmpDir):
                     b"SIMPLE       examples/tests/failtest.sh\n")
         self.assertEqual(expected, result.stdout)
 
-    @skipUnlessPathExists('/bin/sh')
-    def test_loader_and_external_runner_incompatibility(self):
-        """
-        Check if the user is inform about incompatibility between loader and
-        external_runner.
-        """
-        test_script = script.TemporaryScript('simpletest.sh', SIMPLE_TEST,
-                                             'avocado_loader_test',
-                                             mode=self.MODE_0775)
-        test_script.save()
-
-        cmd = ("%s run --loaders=FOO "
-               "--test-runner=runner "
-               "--external-runner=/bin/sh %s") % (AVOCADO, test_script.path)
-        result = process.run(cmd)
-        expected_warning = ("The loaders and external-runner are incompatible."
-                            "The values in loaders will be ignored.")
-        self.assertIn(expected_warning, result.stderr_text)
-
-        cmd = ("%s run --external-runner=/bin/sh %s "
-               "--test-runner=runner" % (AVOCADO, test_script.path))
-        result = process.run(cmd)
-        self.assertNotIn(expected_warning, result.stderr_text)
-
-        test_script.remove()
-
 
 if __name__ == '__main__':
     unittest.main()
