@@ -13,8 +13,7 @@ RUNNER = "%s -m avocado.core.nrunner" % sys.executable
 class NRunnerFeatures(unittest.TestCase):
     @skipUnlessPathExists('/bin/false')
     def test_custom_exit_codes(self):
-        config = {'run.references': ['/bin/false'],
-                  'run.test_runner': 'nrunner',
+        config = {'resolver.references': ['/bin/false'],
                   'runner.exectest.exitcodes.skip': [1]}
         with Job.from_config(job_config=config) as job:
             self.assertEqual(job.run(), 0)
@@ -22,11 +21,10 @@ class NRunnerFeatures(unittest.TestCase):
     @skipUnlessPathExists('/bin/false')
     @skipUnlessPathExists('/bin/true')
     def test_failfast(self):
-        config = {'run.references': ['/bin/true',
-                                     '/bin/false',
-                                     '/bin/true',
-                                     '/bin/true'],
-                  'run.test_runner': 'nrunner',
+        config = {'resolver.references': ['/bin/true',
+                                          '/bin/false',
+                                          '/bin/true',
+                                          '/bin/true'],
                   'run.failfast': True,
                   'nrunner.shuffle': False,
                   'nrunner.max_parallel_tasks': 1}
