@@ -105,30 +105,6 @@ class OutputCheckNone(Test):
         process.run(cmd % ('stderr', '__STDERR_DONT_RECORD_CONTENT__'))
 """
 
-OUTPUT_CHECK_ON_OFF_CONTENT = r"""
-import sys
-
-from avocado import Test
-from avocado.utils import process
-
-
-class OutputCheckOnOff(Test):
-
-    def test(self):
-        cmd = "%s -c \"import sys; sys.%%s.write('%%s')\"" % sys.executable
-        # start with the default behavior
-        process.run(cmd % ('stdout', '__STDOUT_CONTENT__'))
-        process.run(cmd % ('stderr', '__STDERR_CONTENT__'))
-        # now shift to no recording
-        process.run(cmd % ('stdout', '__STDOUT_DONT_RECORD_CONTENT__'),
-                    allow_output_check='none')
-        process.run(cmd % ('stderr', '__STDERR_DONT_RECORD_CONTENT__'),
-                    allow_output_check='none')
-        # now check that the default behavior (recording) is effective
-        process.run(cmd % ('stdout', '__STDOUT_DO_RECORD_CONTENT__'))
-        process.run(cmd % ('stderr', '__STDERR_DO_RECORD_CONTENT__'))
-"""
-
 OUTPUT_SHOW_TEST = """
 #!/usr/bin/env python3
 
@@ -142,29 +118,28 @@ from avocado.core.suite import TestSuite
 class PassTest(Test):
     def test1(self):
         config = {'core.show': ['none'],
-                  'run.references': ['/bin/true']}
+                  'resolver.references': ['/bin/true']}
         suite = TestSuite.from_config(config)
         with Job(config, [suite]) as j:
             j.run()
 
     def test2(self):
         config = {'core.show': ['app'],
-                  'run.references': ['/bin/true']}
+                  'resolver.references': ['/bin/true']}
         suite = TestSuite.from_config(config)
         with Job(config, [suite]) as j:
             j.run()
 
     def test3(self):
         config = {'core.show': ['none'],
-                  'run.references': ['/bin/true']}
+                  'resolver.references': ['/bin/true']}
         suite = TestSuite.from_config(config)
         with Job(config, [suite]) as j:
             j.run()
 
 
 if __name__ == '__main__':
-    config = {'run.references': [__file__],
-              'run.test_runner': 'nrunner',
+    config = {'resolver.references': [__file__],
               'core.show': ['app']}
     suite = TestSuite.from_config(config)
     with Job(config, [suite]) as j:
@@ -192,8 +167,7 @@ class RunnerNRunnerWithFixedTasks(runner_nrunner.Runner):
 
 
 if __name__ == '__main__':
-    config = {'run.test_runner': 'nrunner',
-              'run.references': ['/bin/true', '/bin/false']}
+    config = {'resolver.references': ['/bin/true', '/bin/false']}
     job = Job.from_config(config)
     job.setup()
     job.test_suites[0]._runner = RunnerNRunnerWithFixedTasks()
@@ -216,22 +190,6 @@ def missing_binary(binary):
 
 class OutputTest(TestCaseTmpDir):
 
-    @unittest.skipIf(missing_binary('cc'),
-                     "C compiler is required by the underlying doublefree.py test")
-    def test_output_doublefree(self):
-        cmd_line = ('%s run --job-results-dir %s --disable-sysinfo '
-                    'examples/tests/doublefree.py' % (AVOCADO, self.tmpdir.name))
-        result = process.run(cmd_line, ignore_status=True)
-        expected_rc = exit_codes.AVOCADO_ALL_OK
-        output = result.stdout + result.stderr
-        self.assertEqual(result.exit_status, expected_rc,
-                         "Avocado did not return rc %d:\n%s" %
-                         (expected_rc, result))
-        bad_string = b'double free or corruption'
-        self.assertNotIn(bad_string, output,
-                         "Libc double free can be seen in avocado "
-                         "doublefree output:\n%s" % output)
-
     def test_log_to_debug(self):
         test = script.Script(os.path.join(self.tmpdir.name, "output_test.py"),
                              OUTPUT_TEST_CONTENT)
@@ -322,64 +280,6 @@ class OutputTest(TestCaseTmpDir):
                           output_file.readlines()))
             self.assertEqual(expected, result)
 
-    def test_check_record_no_module_default(self):
-        """
-        Checks that the `avocado.utils.process` module won't have a output
-        check record mode (`OUTPUT_CHECK_RECORD_MODE`) set by default.
-
-        The reason is that, if this is always set from the command
-        line runner, we can't distinguish from a situation where the
-        module level configuration should be applied as a fallback to
-        the API parameter.  By leaving it unset by default, the command line
-        option parameter value `none` will slightly change its behavior,
-        meaning that it will explicitly disable output check record when
-        asked to do so.
-        """
-        with script.Script(os.path.join(self.tmpdir.name, "output_mode_none.py"),
-                           OUTPUT_MODE_NONE_CONTENT,
-                           script.READ_ONLY_MODE) as test:
-            command = ("%s run --job-results-dir %s --disable-sysinfo "
-                       "--test-runner=runner "
-                       "--json - --output-check-record none -- %s") % (AVOCADO,
-                                                                       self.tmpdir.name,
-                                                                       test.path)
-            result = process.run(command)
-            res = json.loads(result.stdout_text)
-            testdir = res["tests"][0]["logdir"]
-            for output_file in ('stdout', 'stderr', 'output'):
-                output_file_path = os.path.join(testdir, output_file)
-                self.assertTrue(os.path.exists(output_file_path))
-                with open(output_file_path, 'r') as output:
-                    self.assertEqual(output.read(), '')
-
-    def test_check_on_off(self):
-        """
-        Checks that output will always be kept, but it will only make into
-        the *test* stdout/stderr/output files when it's not explicitly disabled
-
-        This control is defined as an API parameter, `allow_output_check`, so
-        it should be possible to enable/disable it on each call.
-        """
-        with script.Script(os.path.join(self.tmpdir.name, "test_check_on_off.py"),
-                           OUTPUT_CHECK_ON_OFF_CONTENT,
-                           script.READ_ONLY_MODE) as test:
-            command = ("%s run --job-results-dir %s --disable-sysinfo "
-                       "--test-runner=runner "
-                       "--json - -- %s") % (AVOCADO, self.tmpdir.name, test.path)
-            result = process.run(command)
-            res = json.loads(result.stdout_text)
-            testdir = res["tests"][0]["logdir"]
-            stdout_path = os.path.join(testdir, 'stdout')
-            self.assertTrue(os.path.exists(stdout_path))
-            with open(stdout_path, 'r') as stdout:
-                self.assertEqual(stdout.read(),
-                                 '__STDOUT_CONTENT____STDOUT_DO_RECORD_CONTENT__')
-            stderr_path = os.path.join(testdir, 'stderr')
-            self.assertTrue(os.path.exists(stderr_path))
-            with open(stderr_path, 'r') as stderr:
-                self.assertEqual(stderr.read(),
-                                 '__STDERR_CONTENT____STDERR_DO_RECORD_CONTENT__')
-
     @skipUnlessPathExists('/bin/true')
     def test_show(self):
         """
@@ -509,27 +409,6 @@ class OutputPluginTest(TestCaseTmpDir):
             self.check_output_files(debug_log)
         minidom.parse(tmpfile)
 
-    def test_nonprintable_chars(self):
-        cmd_line = ("%s run --external-runner /bin/ls "
-                    "'NON_EXISTING_FILE_WITH_NONPRINTABLE_CHARS_IN_HERE\x1b' "
-                    "--job-results-dir %s --disable-sysinfo --tap-include-logs"
-                    " --test-runner=runner"
-                    % (AVOCADO, self.tmpdir.name))
-        result = process.run(cmd_line, ignore_status=True)
-        output = result.stdout_text + result.stderr_text
-        expected_rc = exit_codes.AVOCADO_TESTS_FAIL
-        self.assertEqual(result.exit_status, expected_rc,
-                         "Avocado did not return rc %d:\n%s" %
-                         (expected_rc, result))
-        debug_log = None
-        for line in output.splitlines():
-            if "JOB LOG" in line:
-                debug_log = line.split(':', 1)[-1].strip()
-                break
-        self.assertTrue(debug_log, "Unable to get JOB LOG from output:\n%s"
-                        % output)
-        self.check_output_files(debug_log)
-
     def test_show_test(self):
         cmd_line = ('%s --show=test run --job-results-dir %s --disable-sysinfo '
                     'examples/tests/passtest.py' % (AVOCADO, self.tmpdir.name))
