@@ -94,17 +94,15 @@ class JobTest(unittest.TestCase):
         self.assertIsNone(self.job.test_suite)
 
     def test_suite_not_started(self):
-        suite = TestSuite('empty-suite', {'run.test_runner': 'nrunner'})
+        suite = TestSuite('empty-suite')
         self.assertEqual(suite.status, TestSuiteStatus.RESOLUTION_NOT_STARTED)
 
     def test_suite_tests_found(self):
-        suite = TestSuite.from_config({'run.references': ['/bin/true'],
-                                       'run.test_runner': 'nrunner'})
+        suite = TestSuite.from_config({'resolver.references': ['/bin/true']})
         self.assertEqual(suite.status, TestSuiteStatus.TESTS_FOUND)
 
     def test_suite_tests_not_found(self):
-        suite = TestSuite.from_config({'run.references': ['/bin/not-found'],
-                                       'run.test_runner': 'nrunner',
+        suite = TestSuite.from_config({'resolver.references': ['/bin/not-found'],
                                        'run.ignore_missing_references': True})
         self.assertEqual(suite.status, TestSuiteStatus.TESTS_NOT_FOUND)
 
@@ -120,7 +118,7 @@ class JobTest(unittest.TestCase):
         simple_tests_found = self._find_simple_test_candidates()
         config = {'core.show': ['none'],
                   'run.results_dir': self.tmpdir.name,
-                  'run.references': simple_tests_found}
+                  'resolver.references': simple_tests_found}
         self.job = job.Job.from_config(config)
         self.job.setup()
         self.assertEqual(len(simple_tests_found), len(self.job.test_suites[0]))
@@ -135,15 +133,15 @@ class JobTest(unittest.TestCase):
                             if not test_factory[1].get('name', '').endswith('time'):
                                 filtered_test_suite.append(test_factory)
                     elif self.config.get('run.test_runner') == 'nrunner':
-                        task = test_factory
-                        if not task.runnable.uri.endswith('time'):
+                        runnable = test_factory
+                        if not runnable.uri.endswith('time'):
                             filtered_test_suite.append(test_factory)
                 self.test_suite.tests = filtered_test_suite
                 super(JobFilterTime, self).pre_tests()
         simple_tests_found = self._find_simple_test_candidates()
         config = {'core.show': ['none'],
                   'run.results_dir': self.tmpdir.name,
-                  'run.references': simple_tests_found}
+                  'resolver.references': simple_tests_found}
         self.job = JobFilterTime.from_config(config)
         self.job.setup()
         try:
@@ -156,7 +154,7 @@ class JobTest(unittest.TestCase):
         simple_tests_found = self._find_simple_test_candidates(['true'])
         config = {'core.show': ['none'],
                   'run.results_dir': self.tmpdir.name,
-                  'run.references': simple_tests_found}
+                  'resolver.references': simple_tests_found}
         self.job = job.Job.from_config(config)
         self.job.setup()
         self.assertEqual(self.job.run_tests(),
@@ -171,7 +169,7 @@ class JobTest(unittest.TestCase):
         simple_tests_found = self._find_simple_test_candidates()
         config = {'core.show': ['none'],
                   'run.results_dir': self.tmpdir.name,
-                  'run.references': simple_tests_found}
+                  'resolver.references': simple_tests_found}
         self.job = JobLogPost(config)
         self.job.setup()
         self.job.create_test_suite()
@@ -195,8 +193,8 @@ class JobTest(unittest.TestCase):
                                 if not test_factory[1].get('name', '').endswith('time'):
                                     filtered_test_suite.append(test_factory)
                         elif self.config.get('run.test_runner') == 'nrunner':
-                            task = test_factory
-                            if not task.runnable.uri.endswith('time'):
+                            runnable = test_factory
+                            if not runnable.uri.endswith('time'):
                                 filtered_test_suite.append(test_factory)
                     suite.tests = filtered_test_suite
                     super(JobFilterLog, self).pre_tests()
@@ -208,7 +206,7 @@ class JobTest(unittest.TestCase):
         simple_tests_found = self._find_simple_test_candidates()
         config = {'core.show': ['none'],
                   'run.results_dir': self.tmpdir.name,
-                  'run.references': simple_tests_found}
+                  'resolver.references': simple_tests_found}
         self.job = JobFilterLog.from_config(config)
         self.job.setup()
         self.assertEqual(self.job.run(),
@@ -252,12 +250,12 @@ class JobTest(unittest.TestCase):
     def test_job_suites_config(self):
         config = {'run.results_dir': self.tmpdir.name,
                   'core.show': ['none'],
-                  'run.references': ['/bin/true']}
+                  'resolver.references': ['/bin/true']}
 
-        suite_config = {'run.references': ['/bin/false']}
+        suite_config = {'resolver.references': ['/bin/false']}
         self.job = job.Job.from_config(config, [suite_config])
         self.job.setup()
-        self.assertEqual(self.job.config.get('run.references'), ['/bin/true'])
+        self.assertEqual(self.job.config.get('resolver.references'), ['/bin/true'])
 
     def test_job_dryrun_no_unique_job_id(self):
         config = {'run.results_dir': self.tmpdir.name,
@@ -282,7 +280,7 @@ class JobTest(unittest.TestCase):
         config = {'core.show': ['none'],
                   'run.results_dir': self.tmpdir.name}
 
-        suite_config = {'run.references': ['/bin/true']}
+        suite_config = {'resolver.references': ['/bin/true']}
 
         # Manual/Custom method
         suite = TestSuite('foo-test', config=suite_config, job_config=config)
@@ -297,7 +295,7 @@ class JobTest(unittest.TestCase):
                          self.tmpdir.name)
 
         # Automatic method passing only one config
-        config.update({'run.references': ['/bin/true']})
+        config.update({'resolver.references': ['/bin/true']})
         self.job = job.Job.from_config(job_config=config)
         self.assertEqual(self.job.test_suites[0].config.get('run.results_dir'),
                          self.tmpdir.name)
@@ -314,8 +312,7 @@ class JobTest(unittest.TestCase):
     def test_job_make_test_suite_resolver(self):
         simple_tests_found = self._find_simple_test_candidates()
         config = {'run.results_dir': self.tmpdir.name,
-                  'run.references': simple_tests_found,
-                  'run.test_runner': 'nrunner',
+                  'resolver.references': simple_tests_found,
                   'core.show': ['none']}
         self.job = job.Job.from_config(config)
         self.job.setup()
@@ -324,7 +321,7 @@ class JobTest(unittest.TestCase):
             self.assertIsInstance(self.job.test_suite.tests[0], nrunner.Runnable)
 
     def test_job_get_failed_tests(self):
-        config = {'run.references': ['/bin/true', '/bin/false'],
+        config = {'resolver.references': ['/bin/true', '/bin/false'],
                   'run.results_dir': self.tmpdir.name,
                   'core.show': ['none']}
         suite = TestSuite.from_config(config)
@@ -334,7 +331,7 @@ class JobTest(unittest.TestCase):
         self.assertEqual(len(self.job.get_failed_tests()), 1)
 
     def test_job_dryrun(self):
-        config = {'run.references': ['/bin/true', '/bin/false'],
+        config = {'resolver.references': ['/bin/true', '/bin/false'],
                   'run.results_dir': self.tmpdir.name,
                   'run.dry_run.enabled': True,
                   'core.show': ['none']}
@@ -346,9 +343,8 @@ class JobTest(unittest.TestCase):
 
     def test_job_duplicate_suite_names(self):
         config = {'core.show': ['none'],
-                  'run.results_dir': self.tmpdir.name,
-                  'run.test_runner': 'nrunner'}
-        suite_config = {'run.references': ['/bin/true']}
+                  'run.results_dir': self.tmpdir.name}
+        suite_config = {'resolver.references': ['/bin/true']}
         suite_1 = TestSuite('suite', config=suite_config)
         suite_2 = TestSuite('suite', config=suite_config)
         with self.assertRaises(JobTestSuiteDuplicateNameError):
