@@ -70,11 +70,16 @@ class Runnable(unittest.TestCase):
         self.assertEqual(runnable.args, ("/etc/profile",))
         self.assertEqual(runnable.kwargs, {"TERM": "vt3270"})
 
+    def test_identifier_args(self):
+        config = {'runner.identifier_format': '{uri}-{args[0]}'}
+        runnable = nrunner.Runnable('exec-text', 'uri', 'arg1', 'arg2',
+                                    config=config)
+        self.assertEqual(runnable.identifier, 'uri-arg1')
+
     def test_runnable_command_args(self):
         runnable = nrunner.Runnable('noop', 'uri', 'arg1', 'arg2')
         actual_args = runnable.get_command_args()
-        exp_args = ['-k', 'noop', '-u', 'uri', '-c', '{}', '-a', 'arg1',
-                    '-a', 'arg2']
+        exp_args = ['-k', 'noop', '-u', 'uri', '-a', 'arg1', '-a', 'arg2']
         self.assertEqual(actual_args, exp_args)
 
     def test_get_dict(self):
